/**
  * ----------------------------------------------------------------
  * Copyright (C)	ACS-Controlsystem GmbH (2008). All Rights Reserved.
  * Product:		Hydrocont S
  * Device: 		Pressure Meter for PROFIBUS PA
  * 				Hydrocont S (V1.0)
  * Description:	Electronic Device Description (EDD)
  * Autor:		Peter Moosmller PM / ACS-Controlsystem
  * $Revision:		1.00 
  * $Date:		18 February 2008 
  * ----------------------------------------------------------------
*/

MANUFACTURER	 360,
DEVICE_TYPE 	 11 ,
DEVICE_REVISION  1 ,
DD_REVISION 	 1

//#include "SIPASTIDENT01.inc"

#define DEFAULT_VALUE_phys_software_rev "1.0"
//#include "SIPAST_Macros_200.inc"

#define DEFAULT_MANUFACTURER_ID 360
//#define CHECK_PROFILE_REV 0x200
//#include "SIPAST.inc"

#define DEVICE_MANUAL_FILENAME	"|en|ba_hydrocont_s_d_pa_1109_en.pdf"	"|de|ba_hydrocont_s_d_pa_1109_de.pdf"

#define ID_FC_ERROR			3000	


// --- Yt ---------------------------------------------------------------------

#define YT1_LABEL		[func_out_value]
#define YT1_HELP		[func_ai_out_value_help]
#define YT1_VALUE		func1_out_value
#define	YT1_LRV		func1_out_lower_range_value
#define YT1_URV		func1_out_upper_range_value
#include "SI_YT.inc"



/* ================================================================
 *	   Block-Information
 * ================================================================
 */


/* ----------------------------------------------------------------
 *	   Physical Block
 * ----------------------------------------------------------------
 */



#ifdef SW_VERSION1_0
#define DEFAULT_VALUE_phys_software_rev "V1.0             "
#endif

#ifdef SW_VERSION1_1
#define DEFAULT_VALUE_phys_software_rev "1.1             "
#endif

#include "SIPASTPB_200.inc"


VARIABLE phys_blk_profile_rev
{
	LABEL		"Profil-Revision";
	HELP		"Revisionsnummer der Blockprofils.";
	CLASS		CONTAINED;
	TYPE		INTEGER (2)
	{
		{769,	"3.01"}
	}
	HANDLING	READ;
}



VARIABLE phys_software_rev
{
	LABEL		[phys_software_revision];
	HELP		[phys_software_revision_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ;
}

VARIABLE phys_manufacturer_id
{
	LABEL		"Hersteller";
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 360 ;

		{ 1,   [Acromag]						},
		{ 2,   [Allen_Bradley]				},
		{ 3,   [Ametek]						},
		{ 4,   [Analog_Devices]				},
		{ 5,   [Elsag_Bailey]					},
		{ 6,   [Beckman]						},
		{ 7,   [Bell_Microsensor]				},
		{ 8,   [Bourns]						},
		{ 9,   [Bristol_Babcock]				},
		{ 10,  [Brooks_Instrument]			},
		{ 11,  [Chessell]						},
		{ 12,  [Combustion_Engineering]		},
		{ 13,  [Daniel_Industries]			},
		{ 14,  [Delta]						},
		{ 15,  [Dieterich_Standard]			},
		{ 16,  [Dohrmann]						},
		{ 17,  [EH]			},
		{ 18,  [Elsag_Bailey]					},
		{ 19,  [Fisher_Controls]				},
		{ 20,  [Foxboro]						},
		{ 21,  [Fuji]							},
		{ 22,  [Elsag_Bailey]					},
		{ 23,  [Honeywell]					},
		{ 24,  [ITT_Barton]					},
		{ 25,  [KayRay_Sensall]				},
		{ 26,  [Kent]							},
		{ 27,  [Leeds_and_Northrup]			},
		{ 28,  [Leslie]						},
		{ 29,  [M_System_Co]					},
		{ 30,  [Measurex]						},
		{ 31,  [Micro_Motion]					},
		{ 32,  [Moore_Industries]				},
		{ 33,  [Moore_Products]				},
		{ 34,  [Ohkura_Electric]				},
		{ 35,  [Paine]						},
		{ 36,  [Rochester_Instrument_Systems] },
		{ 37,  [Ronan]						},
		{ 38,  [Rosemount]					},
		{ 39,  [Peek_Measurement]				},
		{ 40,  [Schlumberger]					},
		{ 41,  [Sensall]						},
		{ 42,  [Siemens]						},
		{ 43,  [Camille_Bauer]				},
		{ 44,  [Toshiba]						},
		{ 45,  [Transmation]					},
		{ 46,  [Rosemount_Analytical]			},
		{ 47,  [Valmet]						},
		{ 48,  [Valtek]						},
		{ 49,  [Varec]						},
		{ 50,  [Viatran]						},
		{ 51,  [Weed]							},
		{ 52,  [Westinghouse]					},
		{ 53,  [Xomox]						},
		{ 54,  [Yamatake]						},
		{ 55,  [Yokogawa]						},
		{ 56,  [Nuovo_Pignone]				},
		{ 57,  [Promac]						},
		{ 58,  [Exac_Corporation]				},
		{ 59,  [KDG_Mobrey]					},
		{ 60,  [Acrom_Control_System]			},
		{ 61,  [Princo]						},
		{ 62,  [Smar]							},
		{ 63,  [Foxboro_Eckardt]				},
		{ 64,  [Measurement_Technology]		},
		{ 65,  [Applied_System_Technologies]	},
		{ 66,  [Samson]						},
		{ 67,  [Sparling_Instruments]			},
		{ 68,  [Fireye]						},
		{ 69,  [Krohne]						},
		{ 70,  [Betz_Equipment]				},
		{ 71,  [Druck]						},
		{ 72,  [SOR]							},
		{ 73,  [Elcon_Instruments]			},
		{ 74,  [EMCO]							},
		{ 75,  [Termiflex]					},
		{ 76,  [VAF_Instruments]				},
		{ 77,  [Westlock_Controls]			},
		{ 78,  [Drexelbrook]					},
		{ 79,  [saab_tank_control]			},
		{ 80,  [K_TEK]						},
		{ 81,  [Flowdata]						},
		{ 82,  [Draeger]						},
		{ 83,  [Raytek]						},
		{ 84,  [Meridian_Instruments]			},
		{ 85,  [BTG]							},
		{ 86,  [Magnetrol]					},
		{ 87,  [Neles_Controls]				},
		{ 88,  [Milltronics]					},
		{ 89,  [HELIOS]						},
		{ 90,	 [Anderson_Instrument_Company]	},
		{ 91,  [INOR]							},
		{ 92,  [ROBERTSHAW]					},
		{ 93,  [PEPPERL_FUCHS]				},
		{ 94,  [ACCUTECH]						},
		{ 95,  [Flow_Measurement]				},
		{ 96,  [KAMSTRUP]						},
		{ 97,  [Knick]						},
		{ 98,  [VEGA]							},
		{ 99,  [MTS_SYS_CORPS_SENSORS]		},
		{ 100, [Oval]							},
		{ 101, [Masoneilan_DRESSER]			},
		{ 102, [Besta]						},
		{ 103, [Ohmart]						},
		{ 104, [Harold_Beck_and_Sons]			},
		{ 105, [rittmeyer_instrumentation]	},
		{ 106, [rossel_messtechnik]			},
		{ 107, [WIKA]							},
		{ 108, [Bopp_and_Reuther_Heinrichs]	},
		{ 109, [pr_eletronics]				},
		{ 110, [jordan_controls]				},
		{ 111, [valcom]						},
		{ 112, [us_electric_motors]			}, 
		{ 113, [apparatebau_hundsbach]		},
		{ 250, [not_used]						},
		{ 251, [none]							},
		{ 360, "ACS-Control-System"				},
		{ 253, [special]						}
		{ 253,	[special]						}
	}
	HANDLING	READ;
}

VARIABLE phys_tag_desc
{
	LABEL		"TAG";		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32);
	HANDLING	READ & WRITE;
}

COMMAND read_phys_tag_desc
{
	SLOT 0;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_tag_desc
		}
	}
}

COMMAND write_phys_tag_desc
{
	SLOT 0;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_tag_desc
		}
		REPLY
		{
		}
	}
}

VARIABLE phys_diagnosis
{
	LABEL		[phys_diagnosis];
	HELP		[phys_diagnosis_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (4)
	{
		{	0,					[dia_OK],					[dia_OK_help]					},
		{	DIA_HW_ELECTR,			[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
		{	DIA_HW_MECH,			[dia_HW_MECH],				[dia_HW_MECH_help]				},
		{	DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],			[dia_TEMP_MOTOR_help]			},
		{	DIA_TEMP_ELECTR,			[dia_TEMP_ELECTR],			[dia_TEMP_ELECTR_help]			},
		{	DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
		{	DIA_MEASUREMENT,			[dia_MEASUREMENT],			[dia_MEASUREMENT_help]			},
		{	DIA_NOT_INIT,				[dia_NOT_INIT],				[dia_NOT_INIT_help]				},
		{	DIA_INIT_ERR,				[dia_INIT_ERR],				[dia_INIT_ERR_help]				},
		{	DIA_ZERO_ERR,			[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
		{	DIA_SUPPLY,				[dia_SUPPLY],				[dia_SUPPLY_help]				},
		{	DIA_CONF_INVAL,			[dia_CONF_INVAL],			[dia_CONF_INVAL_help]			},
		{	DIA_WARMSTART,			[dia_WARMSTART],			[dia_WARMSTART_help]			},
		{	DIA_COLDSTART,			[dia_COLDSTART],			[dia_COLDSTART_help]			},
		{	DIA_MAINTENANCE,			[dia_MAINTENANCE],			[dia_MAINTENANCE_help]	},
		{	DIA_CHARACT,				[dia_CHARACT],				[dia_CHARACT_help]	},
		{	EXTENSION_AVAILABLE,		[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}
	}
	HANDLING	READ;
#ifdef _V510_
	STYLE "MULTILINE 16 7" ;
#endif

}

COMMAND read_phys_diagnosis
{
	SLOT 0;
	INDEX 29;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_diagnosis
		}
	}
}


VARIABLE device_id
{
	LABEL		"Gertebezeichnung";
	HELP		"Der Name des Gertes";
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "Hydrocont S";
	}
	HANDLING	READ;
}

COMMAND read_device_id
	{
		SLOT 0;
		INDEX 27;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				device_id
			}
		}
	}

// redefines phys_factory_reset from SIPASTPB_200.inc
VARIABLE phys_factory_reset		//optional
{
	LABEL		[phys_factory_reset];
	HELP		[phys_factory_reset_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0;
		{ 0,		[no_function]			},
		{ 1,		[factory_reset_PARAMS]	},
		/*{ 2506, 	[phys_device_reset_cmd] },
		{ 2712, 	[factory_reset_ADDRESS] },*/
	}
	HANDLING	WRITE;
}

VARIABLE nennnullpunkt		//optional
{
	LABEL		"Nullpunkt des Nennmessbereiches";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE nennendpunkt		//optional
{
	LABEL		"Endpunkt des Nennmessbereiches";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
	}
	HANDLING	READ & WRITE;
}

COMMAND read_nennmessbereich
	{
		SLOT 0;
		INDEX 49;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				nennendpunkt, nennnullpunkt
			}
		}
	}

COMMAND write_nennmessbereich
	{
		SLOT 0;
		INDEX 49;
		OPERATION WRITE;
		TRANSACTION
		{
			REQUEST
			{
				nennendpunkt, nennnullpunkt
			}
			REPLY
			{
				
			}
		}
	}

// physical block objects have not the PROFIBUS-PA Profile 2.0 mapping
// in firmware V1.0
//#ifdef SW_VERSION1_0
	COMMAND read_phys_descriptor
	{
		BLOCK physical_block;
		INDEX 20;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				phys_descriptor
			}
		}
	}

	COMMAND write_phys_descriptor
	{
		BLOCK physical_block;
		INDEX 20;
		OPERATION WRITE;
		TRANSACTION
		{
			REQUEST
			{
				phys_descriptor
			}
			REPLY
			{
			}
		}
	}

	COMMAND read_phys_message
	{
		BLOCK physical_block;
		INDEX 21;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				phys_message
			}
		}
	}

	COMMAND write_phys_message
	{
		BLOCK physical_block;		
		INDEX 21;
		OPERATION WRITE;
		TRANSACTION
		{
			REQUEST
			{
				phys_message
			}
			REPLY
			{
			}
		}
	}

	COMMAND read_phys_install_date
	{
		BLOCK physical_block;		
		INDEX 22;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				phys_install_date
			}
		}
	}

	COMMAND write_phys_install_date
	{
		BLOCK physical_block;
		INDEX 22;
		OPERATION WRITE;
		TRANSACTION
		{
			REQUEST
			{
				phys_install_date
			}
			REPLY
			{
			}
		}
	}

VARIABLE Targetmodus		//optional
{
	LABEL		"Zielmodus Gert";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	8;
		{ 8,		"automatisch"		},
		{ 16,		"manuell"	},
		{ 128, 		"Messbetrieb ausgesetzt" },		
	}
	HANDLING	READ & WRITE;
}

COMMAND read_Targetmodus
	{
		SLOT 0;
		INDEX 21;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				Targetmodus
			}
		}
	}

COMMAND write_Targetmodus
	{
		SLOT 0;
		INDEX 21;
		OPERATION WRITE;
		TRANSACTION
		{
			REQUEST
			{
				Targetmodus
			}
			REPLY
			{
			}
		}
	}	

VARIABLE phys_device_certification /* optional */
{
	LABEL		[phys_device_certification];
	HELP		[phys_device_certification_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ;
}

COMMAND read_phys_device_certification
{
	SLOT 0;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_device_certification
		}
	}
}


/* ----------------------------------------------------------------
 *	   Transducer Block
 * ----------------------------------------------------------------
 */
BLOCK transducer_block_1
{
	TYPE	TRANSDUCER;
	NUMBER	1;
}


#define DEF_PRESSURE_UNIT_20										\
		/*	Press	*/												\
		{ 8,   [mbar],					[mbar_help] 			},	\
		{ 7,   [bar],					[bar_help]				},	\
		{ 11,  [PA],					[PA_help]				},	\
		{ 12,  [kPA],					[kPA_help]				},	\
		{ 237, [mega_pascals],			[mega_pascals_help]		},	\
		{ 4,   [mmH2O], 				[mmH2O_help]			},	\
		{ 1,   [InH2O], 				[InH2O_help]			},	\
		{ 3,   [FtH2O], 				[FtH2O_help]			},	\
		{ 6,   [psi],					[psi_help]				},	\
		{ 9,   [g_SqCm],				[g_SqCm_help]			},	\
		{ 10,  [kg_SqCm],				[kg_SqCm_help]			},	\
		{ 14,  [ATM],					[ATM_help]				},	\
		{ 13,  [torr],					[torr_help] 			},	\
		{ 5,   [mmHg],					[mmHg_help] 			},	\
		{ 2,   [InHg],					[InHg_help] 			}	\

#define DEF_SQRT_UNIT_20																	  \
		{ 57,  [Percent],							[Percent_help]							},\
		/*	SQRT	*/																		  \
		{ 15,  [CuFt_min],							[CuFt_min_help] 						},\
		{ 19,  [CuMtr_hr],							[CuMtr_hr_help] 						},\
		{ 24,  [l_s],								[l_s_help]								},\
		{ 26,  [CuFt_s],							[CuFt_s_help]							},\
		{ 28,  [CuMtr_s],							[CuMtr_s_help]							},\
		{ 121, [normal_cubic_meter_per_hour],		[normal_cubic_meter_per_hour_help]		},\
		{ 123, [standard_cubic_feet_per_minute],	[standard_cubic_feet_per_minute_help]	},\
		{ 131, [CuMtr_min], 						[CuMtr_min_help]						},\
		{ 136, [gal_hr],							[gal_hr_help]							},\
		{ 235, [gallons_per_day],					[gallons_per_day_help]					},\
		{ 71,  [g_min],								[g_min_help]							},\
		{ 73,  [kg_s],								[kg_s_help]								},\
		{ 74,  [kg_min],							[kg_min_help]							},\
		{ 75,  [kg_hr],								[kg_hr_help]							},\
		{ 77,  [MetTon_min],						[MetTon_min_help]						},\
		{ 78,  [MetTon_hr],							[MetTon_hr_help]						},\
		{ 79,  [MetTon_day],						[MetTon_day_help]						},\
		{ 80,  [lb_s],								[lb_s_help]								},\
		{ 81,  [lb_min],							[lb_min_help]							},\
		{ 82,  [lb_hr],								[lb_hr_help]							},\
		{ 253, [special]																	} \

#define DEF_LEVEL_LIN_UNIT_20								\
		{ 57,  [Percent],				[Percent_help]		},	\
	/* Length */											\
		{ 48,  [cm],					[cm_help]			},	\
		{ 45,  [meter], 				[meter_help]		},	\
		{ 47,  [in],					[in_help]			},	\
		{ 44,  [ft],					[ft_help]			},	\
	/* Volume */												\
		{ 41,  [liter], 				[liter_help]		},	\
		{ 236, [hecto_liter],			[hecto_liter_help]	},	\
		{ 43,  [CuMtr], 				[CuMtr_help]		},	\
		{ 112, [CuFt],					[CuFt_help] 		},	\
		{ 40,  [gal],					[gal_help]			},	\
		{ 42,  [ImpGal],				[ImpGal_help]		},	\
	/* Mass */													\
		{ 64,  [ShTon], 				[ShTon_help]		},	\
		{ 61,  [kg],					[kg_help]			},	\
		{ 62,  [MetTon],				[MetTon_help]		},	\
		{ 63,  [lb],					[lb_help]			},	\
		{ 253, [special]									}	\

#define DEF_LEVEL_CYL_UNIT_20								\
		{ 57,  [Percent],				[Percent_help]		},	\
	/* Volume */												\
		{ 41,  [liter], 				[liter_help]		},	\
		{ 236, [hecto_liter],			[hecto_liter_help]	},	\
		{ 43,  [CuMtr], 				[CuMtr_help]		},	\
		{ 112, [CuFt],					[CuFt_help] 		},	\
		{ 40,  [gal],					[gal_help]			},	\
		{ 42,  [ImpGal],				[ImpGal_help]		},	\
	/* Mass */													\
		{ 64,  [ShTon], 				[ShTon_help]		},	\
		{ 61,  [kg],					[kg_help]			},	\
		{ 62,  [MetTon],				[MetTon_help]		},	\
		{ 63,  [lb],					[lb_help]			},	\
		{ 253, [special]									}	\


VARIABLE trans1_blk_reserve
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans1_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	3,	[blk_block_object_TRANSDUCER]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[trans_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	1,	[trans_blk_parent_class_PRES]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_class
{
	LABEL		[blk_class];
	HELP		[trans_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	252;
		{	1,		[trans_pres_blk_class_DIFF] },
		{	2,		[trans_pres_blk_class_ABS]	},
		{	3,		[trans_pres_blk_class_GAGE] },
		{	250,	[not_used]					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_dd_reference
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE trans1_blk_dd_rev
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_profile
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_profile_rev
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{		
		{	769,	"3.01"	}
	}
	HANDLING	READ;

}

VARIABLE trans1_blk_execution_time
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;

}

VARIABLE trans1_blk_highest_rel_offset
{
	LABEL		[blk_highest_rel_offset];
	HELP		[blk_highest_rel_offset_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_index_view_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_num_view_lists
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans1_st_rev
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE trans1_tag_desc
{
	LABEL		[tag_desc];
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_strategy
{
	LABEL		[strategy];
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_alert_key
{
	LABEL		[alert_key];
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_target_mode
{
	LABEL		[target_mode];
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_actual_mode
{
	LABEL		[actual_mode];
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ;
}

VARIABLE trans1_permitted_mode
{
	LABEL		[permitted_mode];
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ;
}

VARIABLE trans1_normal_mode
{
	LABEL		[normal_mode];
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ;
}

VARIABLE trans1_current_state_alarm_sum
{
	LABEL		[current_state_alarm_sum];
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_unacknowledged_state_alarm_sum
{
	LABEL		[unacknowledged_state_alarm_sum];
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_unreported_state_alarm_sum
{
	LABEL		[unreported_state_alarm_sum];
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_disabled_state_alarm_sum
{
	LABEL		[disabled_state_alarm_sum];
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

/*---------------------------------------------------------------------*/
/*	  Transducer Block: Pressure Transmitter (m)					   */
/*---------------------------------------------------------------------*/

VARIABLE trans1_sensor_value
{
	LABEL		[trans_pres_sensor_value];
	HELP		[trans_pres_sensor_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE sensor_high_limit
{
	LABEL		[trans_sensor_upper_limit];
	HELP		[trans_sensor_upper_limit_help];
	CLASS		CONTAINED;
	CONSTANT_UNIT	"bar";
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
	}
	HANDLING	READ;
}

VARIABLE sensor_low_limit
{
	LABEL		[trans_sensor_lower_limit];
	HELP		[trans_sensor_lower_limit_help];
	CLASS		CONTAINED;
	CONSTANT_UNIT	"bar";
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE cal_point_hi
{
	LABEL		[trans_cal_point_hi];
	HELP		[trans_cal_point_hi_help];
	CLASS		CONTAINED;
	CONSTANT_UNIT	"bar";
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
		MIN_VALUE			sensor_low_limit;
		MAX_VALUE			sensor_high_limit;
	}
	HANDLING	READ & WRITE;
	PRE_READ_ACTIONS {meth_calib_hi__ermittlung}
}

VARIABLE cal_point_lo
{
	LABEL		[trans_cal_point_lo];
	HELP		[trans_cal_point_lo_help];
	CLASS		CONTAINED;
	CONSTANT_UNIT	"bar";
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE			sensor_low_limit;
		MAX_VALUE			sensor_high_limit;
	}
	HANDLING	READ & WRITE;
	PRE_READ_ACTIONS {meth_calib_lo__ermittlung}
}

VARIABLE cal_min_span
{
	LABEL		[trans_cal_min_span];
	HELP		[trans_cal_min_span_help];
	CLASS		CONTAINED;
	CONSTANT_UNIT	"bar";
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE cal_unit
{
	LABEL		[trans_cal_unit];
	HELP		[trans_cal_unit_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1137;
		{1137, "bar", [bar_help]},		
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS
	{
		meth_trans1_func1_sync
	}
	POST_READ_ACTIONS
	{
		meth_trans1_func1_sync
	}
}

VARIABLE trans1_trimmed_value
{
	LABEL		[trans_pres_trimmed_value];
	HELP		[trans_pres_trimmed_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_trimmed_status
{
	LABEL		[trans_pres_trimmed_status];
	HELP		[trans_pres_trimmed_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
/* bad */
		{	0,	[bad_0] 		},
		{	1,	[bad_1] 		},
		{	2,	[bad_2] 		},
		{	3,	[bad_3] 		},
		{	4,	[bad_4] 		},
		{	5,	[bad_5] 		},
		{	6,	[bad_6] 		},
		{	7,	[bad_7] 		},
		{	8,	[bad_8] 		},
		{	9,	[bad_9] 		},
		{	10, [bad_10]		},
		{	11, [bad_11]		},
		{	12, [bad_12]		},
		{	13, [bad_13]		},
		{	14, [bad_14]		},
		{	15, [bad_15]		},
		{	16, [bad_16]		},
		{	17, [bad_17]		},
		{	18, [bad_18]		},
		{	19, [bad_19]		},
		{	20, [bad_20]		},
		{	21, [bad_21]		},
		{	22, [bad_22]		},
		{	23, [bad_23]		},
		{	24, [bad_24]		},
		{	25, [bad_25]		},
		{	26, [bad_26]		},
		{	27, [bad_27]		},
		{	28, [bad_28]		},
		{	29, [bad_29]		},
		{	30, [bad_30]		},
		{	31, [bad_31]		},
		{	32, [bad_32]		},
		{	33, [bad_33]		},
		{	34, [bad_34]		},
		{	35, [bad_35]		},
/* uncertain */
		{	64, [uncertain_64]	},
		{	65, [uncertain_65]	},
		{	66, [uncertain_66]	},
		{	67, [uncertain_67]	},
		{	68, [uncertain_68]	},
		{	69, [uncertain_69]	},
		{	70, [uncertain_70]	},
		{	71, [uncertain_71]	},
		{	72, [uncertain_72]	},
		{	73, [uncertain_73]	},
		{	74, [uncertain_74]	},
		{	75, [uncertain_75]	},
		{	76, [uncertain_76]	},
		{	77, [uncertain_77]	},
		{	78, [uncertain_78]	},
		{	79, [uncertain_79]	},
		{	80, [uncertain_80]	},
		{	81, [uncertain_81]	},
		{	82, [uncertain_82]	},
		{	83, [uncertain_83]	},
		{	84, [uncertain_84]	},
		{	85, [uncertain_85]	},
		{	86, [uncertain_86]	},
		{	87, [uncertain_87]	},
		{	88, [uncertain_88]	},
		{	89, [uncertain_89]	},
		{	90, [uncertain_90]	},
		{	91, [uncertain_91]	},
		{	92, [uncertain_92]	},
		{	93, [uncertain_93]	},
		{	94, [uncertain_94]	},
		{	95, [uncertain_95]	},
/* good */
		{	128,[good_128]		},
		{	129,[good_129]		},
		{	130,[good_130]		},
		{	131,[good_131]		},
		{	132,[good_132]		},
		{	133,[good_133]		},
		{	134,[good_134]		},
		{	135,[good_135]		},
		{	136,[good_136]		},
		{	137,[good_137]		},
		{	138,[good_138]		},
		{	139,[good_139]		},
		{	140,[good_140]		},
		{	141,[good_141]		},
		{	142,[good_142]		},
		{	143,[good_143]		},
		{	144,[good_144]		},
		{	145,[good_145]		},
		{	146,[good_146]		},
		{	147,[good_147]		},
		{	148,[good_148]		},
		{	149,[good_149]		},
		{	150,[good_150]		},
		{	151,[good_151]		},
		{	152,[good_152]		},
		{	153,[good_153]		},
		{	154,[good_154]		},
		{	155,[good_155]		},
		{	160,[good_160]		},
		{	161,[good_161]		},
		{	162,[good_162]		},
		{	163,[good_163]		}
	}
	HANDLING	READ;
}


VARIABLE trans1_sensor_type
{
	LABEL		[trans_sensor_type];
	HELP		[trans_pres_sensor_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		{	0,		"Diff (DP) PN 160"
					"|de|Diff-Druck PN 160"
					"|fr|Pression Diff PN 160"
					"|sp|Presin dif. PN 160"
					"|it|Pressione differenziale PN 160" },
		{	1,		[gage]							},
		{	2,		[absolute]						},
		{	3,		"Diff (HP) PN 420"
					"|de|Diff-Druck PN 420"
					"|fr|Pression Diff PN 420"
					"|sp|Presin dif. PN 420"
					"|it|Pressione differenziale PN 420" },
		{	4,		[liquid_level]					},
		{	5,		"Draft range (DR) PN 32"
					"|de|Kleiner Diff-Druck PN 32"
					"|fr|Faible pression Diff PN 32"
					"|sp|Presin dif. pequea PN 32"
					"|it|Piccola pressione differenziale PN 32" },
		{	239,	"Diff (DP) PN 315"
					"|de|Diff-Druck PN 315"
					"|fr|Pression Diff PN 315"
					"|sp|Presin dif. Pn 315"
					"|it|Pressione differenziale PN 315" },
		{	253,	[special]						}
	}
	HANDLING	READ;
}

VARIABLE trans1_sensor_num
{
	LABEL		[trans_pres_sensor_serial_num];
	HELP		[trans_pres_sensor_serial_num_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DISPLAY_FORMAT	"8u";
	}
	HANDLING	READ;
}

VARIABLE trans1_primary_value
{
	LABEL		[trans_value];
	HELP		[trans_pres_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_primary_status
{
	LABEL		[trans_value_status];
	HELP		[trans_value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
/* bad */
		{	0,	[bad_0] 		},
		{	1,	[bad_1] 		},
		{	2,	[bad_2] 		},
		{	3,	[bad_3] 		},
		{	4,	[bad_4] 		},
		{	5,	[bad_5] 		},
		{	6,	[bad_6] 		},
		{	7,	[bad_7] 		},
		{	8,	[bad_8] 		},
		{	9,	[bad_9] 		},
		{	10, [bad_10]		},
		{	11, [bad_11]		},
		{	12, [bad_12]		},
		{	13, [bad_13]		},
		{	14, [bad_14]		},
		{	15, [bad_15]		},
		{	16, [bad_16]		},
		{	17, [bad_17]		},
		{	18, [bad_18]		},
		{	19, [bad_19]		},
		{	20, [bad_20]		},
		{	21, [bad_21]		},
		{	22, [bad_22]		},
		{	23, [bad_23]		},
		{	24, [bad_24]		},
		{	25, [bad_25]		},
		{	26, [bad_26]		},
		{	27, [bad_27]		},
		{	28, [bad_28]		},
		{	29, [bad_29]		},
		{	30, [bad_30]		},
		{	31, [bad_31]		},
		{	32, [bad_32]		},
		{	33, [bad_33]		},
		{	34, [bad_34]		},
		{	35, [bad_35]		},
/* uncertain */
		{	64, [uncertain_64]	},
		{	65, [uncertain_65]	},
		{	66, [uncertain_66]	},
		{	67, [uncertain_67]	},
		{	68, [uncertain_68]	},
		{	69, [uncertain_69]	},
		{	70, [uncertain_70]	},
		{	71, [uncertain_71]	},
		{	72, [uncertain_72]	},
		{	73, [uncertain_73]	},
		{	74, [uncertain_74]	},
		{	75, [uncertain_75]	},
		{	76, [uncertain_76]	},
		{	77, [uncertain_77]	},
		{	78, [uncertain_78]	},
		{	79, [uncertain_79]	},
		{	80, [uncertain_80]	},
		{	81, [uncertain_81]	},
		{	82, [uncertain_82]	},
		{	83, [uncertain_83]	},
		{	84, [uncertain_84]	},
		{	85, [uncertain_85]	},
		{	86, [uncertain_86]	},
		{	87, [uncertain_87]	},
		{	88, [uncertain_88]	},
		{	89, [uncertain_89]	},
		{	90, [uncertain_90]	},
		{	91, [uncertain_91]	},
		{	92, [uncertain_92]	},
		{	93, [uncertain_93]	},
		{	94, [uncertain_94]	},
		{	95, [uncertain_95]	},
/* good */
		{	128,[good_128]		},
		{	129,[good_129]		},
		{	130,[good_130]		},
		{	131,[good_131]		},
		{	132,[good_132]		},
		{	133,[good_133]		},
		{	134,[good_134]		},
		{	135,[good_135]		},
		{	136,[good_136]		},
		{	137,[good_137]		},
		{	138,[good_138]		},
		{	139,[good_139]		},
		{	140,[good_140]		},
		{	141,[good_141]		},
		{	142,[good_142]		},
		{	143,[good_143]		},
		{	144,[good_144]		},
		{	145,[good_145]		},
		{	146,[good_146]		},
		{	147,[good_147]		},
		{	148,[good_148]		},
		{	149,[good_149]		},
		{	150,[good_150]		},
		{	151,[good_151]		},
		{	152,[good_152]		},
		{	153,[good_153]		},
		{	154,[good_154]		},
		{	155,[good_155]		},
		{	160,[good_160]		},
		{	161,[good_161]		},
		{	162,[good_162]		},
		{	163,[good_163]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_primary_value_type
{
	LABEL		[trans_pres_primary_value_type];
	HELP		[trans_pres_primary_value_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		{	0,		[differential]			},
		{	1,		[gage]					},
		{	2,		"Level"
					"|de|Fllstand"
					"|fr|Niveau"
					"|sp|Nivel"
					"|it|Livello di riempimento" },
		{	3,		"Flow"
					"|de|Durchflu"
					"|fr|Dbit"
					"|sp|Flujo"
					"|it|Portata" },
		{	4,		"Temperature"
					"|de|Temperatur"
					"|fr|Temprature"
					"|sp|Temperatura"
					"|it|Temperatura"	},
		{	253,	[special]				}
	}
	HANDLING	READ;
}

 
VARIABLE trans1_primary_value_unit
{
	LABEL		"Einheit(Input)";//[trans_pres_primary_value_unit];
	HELP		[trans_pres_primary_value_unit_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER 
	{
		DEFAULT_VALUE	1137;

		{1137, "bar", [bar_help]},
		{1133, "kPa", [kPa_help]},		
		{1138,"mbar", [mbar_help]},
		{1141, "PSI", [psi_help]}
	}
	HANDLING	IF (linearisation_mode > 0)
				{
					READ & WRITE;
				}
				ELSE
				{
					READ;
				}

	VALIDITY	IF (linearisation_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	POST_EDIT_ACTIONS
	{
		meth_trans1_func1_sync,
		meth_post_edit_unit
	}
	POST_READ_ACTIONS
	{
		meth_trans1_func1_sync
	}
	PRE_EDIT_ACTIONS
	{
		meth_pre_edit_unit
	}
}

METHOD	meth_calib_lo__ermittlung
{
	DEFINITION
	{
		int i1, i2;
	
		i1=ivar_value(channel);
		if (i1==326){
			i2=64;
			iassign(calib_lo_index, i2);
		}
		else{
			i2=128;
			iassign(calib_lo_index, i2);
		}
	}
}

METHOD	meth_calib_hi__ermittlung
{
	DEFINITION
	{
		int i1, i2;
		i2 = 
		i1=ivar_value(channel);
		if (i1==326){
			i2=63;
			iassign(calib_hi_index, i2);
		}
		else{
			i2=129;
			iassign(calib_hi_index, i2);
		}
	}
}


VARIABLE calib_lo_index
{
	//LABEL		[std_V2H6];	
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2)
	{
		DEFAULT_VALUE	IF(channel == 326)
				{
					64;
				}
				ELSE	
				{
					128;
				}
	}
}

VARIABLE calib_hi_index
{
	//LABEL		[std_V2H6];	
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2)
	{
		DEFAULT_VALUE	IF(channel == 326)
				{
					63;
				}
				ELSE	
				{
					129;
				}
	}
}

METHOD meth_trans1_func1_sync
{
	DEFINITION
	{
		int i1, i2;
		i1=ivar_value(linearisation_mode);
		if (i1!=0){
			i2=ivar_value(trans1_primary_value_unit);
			iassign(pv_unit, i2);
		}
		else{
			i2=ivar_value(cal_unit);
			iassign(pv_unit, i2);
		}
	}
}


/* ----------------------------------------------------------------
 *	   Transducer Block Fllstand
 * ----------------------------------------------------------------
 */
BLOCK transducer_block_2
{
	TYPE	TRANSDUCER;
	NUMBER	2;
}


#define DEF_PRESSURE_UNIT_20										\
		/*	Press	*/												\
		{ 8,   [mbar],					[mbar_help] 			},	\
		{ 7,   [bar],					[bar_help]				},	\
		{ 11,  [PA],					[PA_help]				},	\
		{ 12,  [kPA],					[kPA_help]				},	\
		{ 237, [mega_pascals],			[mega_pascals_help]		},	\
		{ 4,   [mmH2O], 				[mmH2O_help]			},	\
		{ 1,   [InH2O], 				[InH2O_help]			},	\
		{ 3,   [FtH2O], 				[FtH2O_help]			},	\
		{ 6,   [psi],					[psi_help]				},	\
		{ 9,   [g_SqCm],				[g_SqCm_help]			},	\
		{ 10,  [kg_SqCm],				[kg_SqCm_help]			},	\
		{ 14,  [ATM],					[ATM_help]				},	\
		{ 13,  [torr],					[torr_help] 			},	\
		{ 5,   [mmHg],					[mmHg_help] 			},	\
		{ 2,   [InHg],					[InHg_help] 			}	\

#define DEF_SQRT_UNIT_20																	  \
		{ 57,  [Percent],							[Percent_help]							},\
		/*	SQRT	*/																		  \
		{ 15,  [CuFt_min],							[CuFt_min_help] 						},\
		{ 19,  [CuMtr_hr],							[CuMtr_hr_help] 						},\
		{ 24,  [l_s],								[l_s_help]								},\
		{ 26,  [CuFt_s],							[CuFt_s_help]							},\
		{ 28,  [CuMtr_s],							[CuMtr_s_help]							},\
		{ 121, [normal_cubic_meter_per_hour],		[normal_cubic_meter_per_hour_help]		},\
		{ 123, [standard_cubic_feet_per_minute],	[standard_cubic_feet_per_minute_help]	},\
		{ 131, [CuMtr_min], 						[CuMtr_min_help]						},\
		{ 136, [gal_hr],							[gal_hr_help]							},\
		{ 235, [gallons_per_day],					[gallons_per_day_help]					},\
		{ 71,  [g_min],								[g_min_help]							},\
		{ 73,  [kg_s],								[kg_s_help]								},\
		{ 74,  [kg_min],							[kg_min_help]							},\
		{ 75,  [kg_hr],								[kg_hr_help]							},\
		{ 77,  [MetTon_min],						[MetTon_min_help]						},\
		{ 78,  [MetTon_hr],							[MetTon_hr_help]						},\
		{ 79,  [MetTon_day],						[MetTon_day_help]						},\
		{ 80,  [lb_s],								[lb_s_help]								},\
		{ 81,  [lb_min],							[lb_min_help]							},\
		{ 82,  [lb_hr],								[lb_hr_help]							},\
		{ 253, [special]																	} \

#define DEF_LEVEL_LIN_UNIT_20								\
		{ 57,  [Percent],				[Percent_help]		},	\
	/* Length */											\
		{ 48,  [cm],					[cm_help]			},	\
		{ 45,  [meter], 				[meter_help]		},	\
		{ 47,  [in],					[in_help]			},	\
		{ 44,  [ft],					[ft_help]			},	\
	/* Volume */												\
		{ 41,  [liter], 				[liter_help]		},	\
		{ 236, [hecto_liter],			[hecto_liter_help]	},	\
		{ 43,  [CuMtr], 				[CuMtr_help]		},	\
		{ 112, [CuFt],					[CuFt_help] 		},	\
		{ 40,  [gal],					[gal_help]			},	\
		{ 42,  [ImpGal],				[ImpGal_help]		},	\
	/* Mass */													\
		{ 64,  [ShTon], 				[ShTon_help]		},	\
		{ 61,  [kg],					[kg_help]			},	\
		{ 62,  [MetTon],				[MetTon_help]		},	\
		{ 63,  [lb],					[lb_help]			},	\
		{ 253, [special]									}	\

#define DEF_LEVEL_CYL_UNIT_20								\
		{ 57,  [Percent],				[Percent_help]		},	\
	/* Volume */												\
		{ 41,  [liter], 				[liter_help]		},	\
		{ 236, [hecto_liter],			[hecto_liter_help]	},	\
		{ 43,  [CuMtr], 				[CuMtr_help]		},	\
		{ 112, [CuFt],					[CuFt_help] 		},	\
		{ 40,  [gal],					[gal_help]			},	\
		{ 42,  [ImpGal],				[ImpGal_help]		},	\
	/* Mass */													\
		{ 64,  [ShTon], 				[ShTon_help]		},	\
		{ 61,  [kg],					[kg_help]			},	\
		{ 62,  [MetTon],				[MetTon_help]		},	\
		{ 63,  [lb],					[lb_help]			},	\
		{ 253, [special]									}	\


VARIABLE trans2_blk_reserve
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans2_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	3,	[blk_block_object_TRANSDUCER]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[trans_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	4,	"Fllstand"	}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_class
{
	LABEL		[blk_class];
	HELP		[trans_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	252;
		{	1,		"Hydrostatisch" },
		{	2,		"Absolut-differenziell"	},
		{	250,	[not_used]					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_dd_reference
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE trans2_blk_dd_rev
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans2_blk_profile
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans2_blk_profile_rev
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{		
		{	769,	"3.01"	}
	}
	HANDLING	READ;

}

VARIABLE trans2_blk_execution_time
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;

}


VARIABLE trans2_target_mode
{
	LABEL		[target_mode];
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans2_actual_mode
{
	LABEL		[actual_mode];
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ;
}

VARIABLE trans2_permitted_mode
{
	LABEL		[permitted_mode];
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ;
}

VARIABLE trans2_normal_mode
{
	LABEL		[normal_mode];
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO] 			}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_highest_rel_offset
{
	LABEL		[blk_highest_rel_offset];
	HELP		[blk_highest_rel_offset_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans2_blk_index_view_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans2_blk_num_view_lists
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans2_tag_desc
{
	LABEL		[tag_desc];
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32);
	HANDLING	READ & WRITE;
}

VARIABLE trans2_strategy
{
	LABEL		[strategy];
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE trans2_alert_key
{
	LABEL		[alert_key];
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

COMMAND read_trans2_target_mode
{
	SLOT 1;
	INDEX 113;
	OPERATION  READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_target_mode
		}
	}
}

COMMAND write_trans2_target_mode
{
	SLOT 1;
	INDEX 113;
	OPERATION  WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_target_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_mode
{
	SLOT 1;
	INDEX 114;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans2_actual_mode, trans2_permitted_mode, trans2_normal_mode
		}
	}
}

COMMAND read_trans2_alarm
{
	SLOT 1;
	INDEX 114;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_current_state_alarm_sum, trans2_unacknowledged_state_alarm_sum,
			trans2_unreported_state_alarm_sum, trans2_disabled_state_alarm_sum
		}
	}
}

VARIABLE trans2_current_state_alarm_sum
{
	LABEL		[current_state_alarm_sum];
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_unacknowledged_state_alarm_sum
{
	LABEL		[unacknowledged_state_alarm_sum];
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_unreported_state_alarm_sum
{
	LABEL		[unreported_state_alarm_sum];
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_disabled_state_alarm_sum
{
	LABEL		[disabled_state_alarm_sum];
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000, [limit_state_NO_ALARM]	},
		{	0x8000, [limit_state_ST_REV]	}
	}
	HANDLING	READ;
}


COMMAND read_trans2_blk
{
	//BLOCK transducer_block_2;
	SLOT 1;
	INDEX 108;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_blk_reserve, trans2_blk_object, trans2_blk_parent_class, trans2_blk_class,
			trans2_blk_dd_reference, trans2_blk_dd_rev, trans2_blk_profile, trans2_blk_profile_rev,
			trans2_blk_execution_time, trans2_blk_highest_rel_offset, trans2_blk_index_view_1,
			trans2_blk_num_view_lists
		}
	}
}

VARIABLE wertepaar_x1
{
	LABEL		"Wertepaar X1";
	HELP		"Erstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y1
{
	LABEL		"Wertepaar y1";
	HELP		"Erstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x2
{
	LABEL		"Wertepaar X2";
	HELP		"Zweites Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y2
{
	LABEL		"Wertepaar y2";
	HELP		"Zweites Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x3
{
	LABEL		"Wertepaar X3";
	HELP		"Drittes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y3
{
	LABEL		"Wertepaar y3";
	HELP		"Drittes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x4
{
	LABEL		"Wertepaar X4";
	HELP		"Viertes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y4
{
	LABEL		"Wertepaar y4";
	HELP		"Viertes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x5
{
	LABEL		"Wertepaar X5";
	HELP		"Fnftes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y5
{
	LABEL		"Wertepaar y5";
	HELP		"Fnftes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x6
{
	LABEL		"Wertepaar X6";
	HELP		"Sechstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y6
{
	LABEL		"Wertepaar y6";
	HELP		"Sechstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x7
{
	LABEL		"Wertepaar X7";
	HELP		"Siebtes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y7
{
	LABEL		"Wertepaar y7";
	HELP		"Siebtes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x8
{
	LABEL		"Wertepaar X8";
	HELP		"Achtes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y8
{
	LABEL		"Wertepaar y8";
	HELP		"Achtes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x9
{
	LABEL		"Wertepaar X9";
	HELP		"Neuntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y9
{
	LABEL		"Wertepaar y9";
	HELP		"Neuntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x10
{
	LABEL		"Wertepaar X10";
	HELP		"Zehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y10
{
	LABEL		"Wertepaar y10";
	HELP		"Zehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x11
{
	LABEL		"Wertepaar X11";
	HELP		"Elftes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y11
{
	LABEL		"Wertepaar y11";
	HELP		"Elftes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x12
{
	LABEL		"Wertepaar X12";
	HELP		"Zwlftes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y12
{
	LABEL		"Wertepaar y12";
	HELP		"Zwlftes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x13
{
	LABEL		"Wertepaar X13";
	HELP		"Dreizehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y13
{
	LABEL		"Wertepaar y13";
	HELP		"Dreizehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x14
{
	LABEL		"Wertepaar X14";
	HELP		"Vierzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y14
{
	LABEL		"Wertepaar y14";
	HELP		"Vierzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x15
{
	LABEL		"Wertepaar X15";
	HELP		"Fnfzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y15
{
	LABEL		"Wertepaar y15";
	HELP		"Fnfzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x16
{
	LABEL		"Wertepaar X16";
	HELP		"Sechzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y16
{
	LABEL		"Wertepaar y16";
	HELP		"Sechzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x17
{
	LABEL		"Wertepaar X17";
	HELP		"Siebzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y17
{
	LABEL		"Wertepaar y17";
	HELP		"Siebzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x18
{
	LABEL		"Wertepaar X18";
	HELP		"Achtzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y18
{
	LABEL		"Wertepaar y18";
	HELP		"Achtzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x19
{
	LABEL		"Wertepaar X19";
	HELP		"Neunzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y19
{
	LABEL		"Wertepaar y19";
	HELP		"Neunzehntes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x20
{
	LABEL		"Wertepaar X20";
	HELP		"Zwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y20
{
	LABEL		"Wertepaar y20";
	HELP		"Zwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x21
{
	LABEL		"Wertepaar X21";
	HELP		"Einundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y21
{
	LABEL		"Wertepaar y21";
	HELP		"Einundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x22
{
	LABEL		"Wertepaar X22";
	HELP		"Zweiundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y22
{
	LABEL		"Wertepaar y22";
	HELP		"Zweiundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x23
{
	LABEL		"Wertepaar X23";
	HELP		"Dreiundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y23
{
	LABEL		"Wertepaar y23";
	HELP		"Dreiundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x24
{
	LABEL		"Wertepaar X24";
	HELP		"Vierundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y24
{
	LABEL		"Wertepaar y24";
	HELP		"Vierundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_x25
{
	LABEL		"Wertepaar X25";
	HELP		"Fnfundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}

VARIABLE wertepaar_y25
{
	LABEL		"Wertepaar y25";
	HELP		"Fnfundzwanzigstes Wertepaar der Linearisierungstabelle.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	VALIDITY	IF (lintab_edit_mode > 0)
				{
					TRUE;
				}
				ELSE
				{
					FALSE;
				}
	HANDLING	READ & WRITE;	
}




/**
  * ----------------------------------------------------------------
  *       Unit relations
  * ----------------------------------------------------------------
  */

/* table relation: Function Block Analog Input */
UNIT AI_PV_SCALE_UNIT_EH1
{
	IF (linearisation_mode == 0)		 // if pressure
	{
		profil_par.std_V0H9 			//V0H9
	}
	ELSE
	{
		trans1_primary_value_unit		//V3H3
	}
	:
	trans1_primary_value,				//V0H0
}


/* Table unit relation: Pressure Transducer Block */
UNIT TB_SENSOR_UNIT_EH2
{
	profil_par.std_V0H9:			 //V0H9

	cal_point_lo,			 //V7H4
	cal_point_hi,			 //V7H5
	cal_min_span,
	trans1_sensor_value,			 //V7H8
}


// Die folgenden beiden Unit-Relations sind bereits in der SIPASTAI1_200.inc
// definiert.

UNIT AI_UNIT
{
	IF (channel == 326)		 // if pressure
	{
		pv_unit
	}
	ELSE
	{
		pv_f_unit
	}
	:
	pv_upper_range_value,
	pv_lower_range_value
}


UNIT FUNC_OUT_UNIT
{
	func1_out_unit:
	func1_out_value,
	simulation_wert
}



/**
  * ----------------------------------------------------------------
  *       Transducer Block Commands
  * ----------------------------------------------------------------
  */
COMMAND read_trans1_blk
{
	BLOCK transducer_block_1;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_blk_reserve, trans1_blk_object, trans1_blk_parent_class, trans1_blk_class,
			trans1_blk_dd_reference, trans1_blk_dd_rev, trans1_blk_profile, trans1_blk_profile_rev,
			trans1_blk_execution_time, trans1_blk_highest_rel_offset, trans1_blk_index_view_1,
			trans1_blk_num_view_lists
		}
	}
}

COMMAND read_trans1_st_rev
{
	BLOCK transducer_block_1;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_st_rev
		}
	}
}

COMMAND read_trans1_tag_desc
{
	BLOCK transducer_block_1;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tag_desc
		}
	}
}

COMMAND write_trans1_tag_desc
{
	BLOCK transducer_block_1;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_tag_desc
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_strategy
{
	BLOCK transducer_block_1;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_strategy
		}
	}
}

COMMAND write_trans1_strategy
{
	BLOCK transducer_block_1;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_strategy
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_alert_key
{
	BLOCK transducer_block_1;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_alert_key
		}
	}
}

COMMAND write_trans1_alert_key
{
	BLOCK transducer_block_1;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_alert_key
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_target_mode
{
	BLOCK transducer_block_1;
	INDEX 5;
	OPERATION  READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_target_mode
		}
	}
}

COMMAND write_trans1_target_mode
{
	BLOCK transducer_block_1;
	INDEX 5;
	OPERATION  WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_target_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_mode
{
	BLOCK transducer_block_1;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans1_actual_mode, trans1_permitted_mode, trans1_normal_mode
		}
	}
}

COMMAND read_trans1_alarm
{
	BLOCK transducer_block_1;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_current_state_alarm_sum, trans1_unacknowledged_state_alarm_sum,
			trans1_unreported_state_alarm_sum, trans1_disabled_state_alarm_sum
		}
	}
}

COMMAND read_trans1_sensor_value
{
	BLOCK transducer_block_1;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_value
		}
	}
}

COMMAND read_trans1_sensor_high_limit
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			sensor_high_limit
		}
	}
}

COMMAND read_trans1_sensor_low_limit
{
	BLOCK transducer_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			sensor_low_limit
		}
	}
}

COMMAND read_trans1_cal_point_hi
{
	SLOT 1;
	INDEX calib_hi_index;
		
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			cal_point_hi
		}
	}
}

COMMAND write_trans1_cal_point_hi
{
	SLOT 1;
	INDEX calib_hi_index;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			cal_point_hi
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_cal_point_lo
{
	SLOT 1;
	INDEX calib_lo_index;
	OPERATION  READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			cal_point_lo
		}
	}
}

COMMAND write_trans1_cal_point_lo
{
	SLOT 1;
	INDEX calib_lo_index;
	OPERATION  WRITE;
	TRANSACTION
	{
		REQUEST
		{
			cal_point_lo
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_cal_min_span
{
	BLOCK transducer_block_1;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			cal_min_span
		}
	}
}

COMMAND read_trans1_cal_unit
{
	BLOCK transducer_block_1;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			cal_unit
		}
	}
}

COMMAND write_trans1_cal_unit
{
	BLOCK transducer_block_1;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			cal_unit
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_trimmed_value
{
	BLOCK transducer_block_1;
	INDEX 15;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_trimmed_value, trans1_trimmed_status
		}
	}
}

COMMAND read_trans1_sensor_type
{
	BLOCK transducer_block_1;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans1_sensor_type
		}
	}
}

COMMAND read_trans1_sensor_num
{
	BLOCK transducer_block_1;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_num
		}
	}
}

COMMAND read_trans1_primary
{
	BLOCK transducer_block_1;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans1_primary_value, trans1_primary_status
		}
	}
}

COMMAND read_trans1_primary_value_unit
{
	BLOCK transducer_block_1;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			pv_unit //trans1_primary_value_unit
		}
	}
}

COMMAND write_trans1_primary_value_unit
{
	BLOCK transducer_block_1;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pv_unit //trans1_primary_value_unit
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_primary_value_type
{
	BLOCK transducer_block_1;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_primary_value_type
		}
	}
}

COMMAND read_trans2_primary_value_unit
{
	SLOT 1;
	INDEX 117;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			pv_f_unit //trans1_primary_value_unit
		}
	}
}

COMMAND write_trans2_primary_value_unit
{
	SLOT 1;
	INDEX 117;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pv_f_unit //trans1_primary_value_unit
		}
		REPLY
		{
		}
	}
}


COMMAND read_op_code
	{
		SLOT 1;
		INDEX 148;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
				
			}
			REPLY
			{
				op_code_1
			}	
		}
	}

COMMAND write_op_code
	{
		SLOT 1;
		INDEX 148;
		OPERATION WRITE;
		TRANSACTION
		{
			REQUEST
			{
				op_code_1
			}
			REPLY
			{
			}
		}
	}

	
VARIABLE wartungsintervall
{
	LABEL		"Wartungsintervall";
	HELP		"Zeitraum nach dessen Ablauf ber das Diagnosebyte eine Meldung abgegeben werden soll, dass eine Wartung fllig ist.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE		0;
		MIN_VALUE			0;
		MAX_VALUE			63072000;
		
		DISPLAY_FORMAT		".0f";
	}

	HANDLING	READ & WRITE;
	CONSTANT_UNIT	"s";	
}

COMMAND	read_wartungsintervall
{
	SLOT 0;
	INDEX 50;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			wartungsintervall
		}
	}
}

COMMAND write_wartungsintervall
{
	SLOT 0;
	INDEX 50;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			wartungsintervall
		}
		REPLY
		{
		}
	}
}

VARIABLE wartungstimer
{
	LABEL		"Wartungstimer";
	HELP		"Noch verbleibende Zeit bis zum Ablauf des Wartungsintervalls.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
	CONSTANT_UNIT		"s";	
	DISPLAY_FORMAT		".0f";
}

COMMAND	read_wartungstimer
{
	SLOT 0;
	INDEX 51;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			wartungstimer
		}
	}
}

COMMAND write_wartungstimer
{
	SLOT 0;
	INDEX 51;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			wartungstimer
		}
		REPLY
		{
		}
	}
}

VARIABLE ueberlastzaehler
{
	LABEL		"Ueberlastzaehler";
	HELP		"Anzahl der Ueberschreitungen bzw. Unterschreitungen der fr diese Messzelle spezifizierten absoluten Ober- bzw. Untergrenze.";
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
		
}

COMMAND	read_ueberlastzaehler
{
	SLOT 0;
	INDEX 52;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			ueberlastzaehler
		}
	}
}
COMMAND	write_ueberlastzaehler
{
	SLOT 0;
	INDEX 52;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			ueberlastzaehler
		}
		REPLY
		{
			
		}
	}
}


VARIABLE linearisation_mode
{
	LABEL		"Linearisierungsmodus";
	HELP		"Hier wird eingestellt, ob eine Linearisierung mittels einer Tabelle stattfindet oder nicht.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{0, 	[trans1_ms_linearisation_mode_0]	},
		{1, 	[trans1_ms_linearisation_mode_1]	},
		{241,	[trans1_ms_linearisation_mode_241]	},
		{240,	[trans1_ms_linearisation_mode_240]	},
		{242,	[trans1_ms_linearisation_mode_242]	}
	}
	POST_EDIT_ACTIONS	{
		meth_post_trans1_lin_type,
		meth_trans1_func1_sync
	}
	POST_READ_ACTIONS	{
		meth_post_trans1_lin_type,
		meth_trans1_func1_sync
	}
	HANDLING	READ & WRITE;
}
METHOD meth_post_trans1_lin_type
{
	CLASS INPUT;
	DEFINITION
	{
		switch (linearisation_mode)
		{
			case 0: trans1_primary_value_unit = 7;
					break;
			case 1:trans1_primary_value_unit = 57;
					break;
			case 241:trans1_primary_value_unit = 57;
					break;
			case 240:trans1_primary_value_unit = 57;
					break;
			case 242:trans1_primary_value_unit = 57;
					break;
			default: trans1_primary_value_unit = 7;
		}
	}
}
//fbi	Achtung Slot1 Index 133 zwei mal definiert!!!
COMMAND read_trans1_ms_linearisation_mode
{
	/*BLOCK transducer_block_1;
	INDEX 50;*/
	SLOT 1;
	INDEX	133;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			linearisation_mode
		}
	}
}
//fbi	Achtung Slot1 Index 133 zwei mal definiert!!!
COMMAND write_trans1_ms_linearisation_mode
{
	/*BLOCK transducer_block_1;
	INDEX 50;*/
	SLOT 1;
	INDEX	133;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			linearisation_mode
		}
		REPLY
		{
		}
	}
}



METHOD meth_pre_edit_unit
{
	LABEL "meth_pre_change_unit";
	DEFINITION
	{
		float f;
		
/*	fbi; erst trans1_ms_display_lowrange_val definieren!		
		f = fvar_value(trans1_ms_display_lowrange_val);
		fassign(loc_trans1_ms_display_lowrange_val, f);
		f = fvar_value(trans1_ms_display_uprange_val);
		fassign(loc_trans1_ms_display_uprange_val, f);
*/
	}
}
METHOD meth_post_edit_unit
{
	LABEL "meth_pre_change_unit";
	DEFINITION
	{
		float f;
/*	fbi; erst trans1_ms_display_lowrange_val definieren!		
		f = fvar_value(loc_trans1_ms_display_lowrange_val);
		fassign(trans1_ms_display_lowrange_val, f);
		f = fvar_value(loc_trans1_ms_display_uprange_val);
		fassign(trans1_ms_display_uprange_val, f);
*/		
	}
}

	


VARIABLE lintab_edit_mode
{
	LABEL		"Linearisierungsmodus";
	HELP		"Hier wird eingestellt, ob eine Linearisierung mittels einer Tabelle stattfindet oder nicht.";
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0, "linear"},
		{	1, "Linearisierungstabelle"}
	}
	POST_READ_ACTIONS
	{
		IF(lintab_edit_mode == 1)
		{
			meth_linearisierungspunkte_einblenden
		}
	}
}
COMMAND read_trans1_ms_lintab_edit_mode
{
	/*BLOCK transducer_block_1;
	INDEX 55;*/
	SLOT 1;
	INDEX 133;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			lintab_edit_mode
		}
	}
}
COMMAND write_trans1_ms_lintab_edit_mode
{
	/*BLOCK transducer_block_1;
	INDEX 55;*/
	SLOT 1;
	INDEX 133;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			lintab_edit_mode
		}
		REPLY
		{
		}
	}
}

VARIABLE lintab_status
{
	LABEL		"Status Linearisierungstabelle";
	HELP		"Der Status der bertragenen bzw. momentan gltigen Linearisierungstabelle.";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
		{0, "Nicht initialisiert"},
		{1, "Geladene Tabelle ist gltig!"},
		{7, "bertragene Tabelle ist nicht gltig, alte Werte gelten weiterhin."},
		{25,"bertragene Tabelle ist nicht gltig, Tabelle ist weiterhin nicht initialisiert."},
	}
	
}

COMMAND read_lintab_status
{	
	SLOT 1;
	INDEX 149;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			lintab_status
		}
	}
}

VARIABLE lintab_no
{
	LABEL		"Nummernindex Linearisierungstabelle";
	HELP		"Index der auf einen Eintrag in der Linearisierungstabelle verweist, der gerade angezeigt wird bzw. beim nchsten AUslesevorgang ausgelesen wird.";
	CLASS		CONTAINED;
	HANDLING
		IF(lintab_edit_mode == 1)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 24;
	}
	
}

METHOD 	meth_linearisierungspunkte_einblenden
{
	LABEL "Linearisierung einblenden";
	DEFINITION
	{

	}
}

METHOD	meth_op_code_setzen
{
	LABEL "Linearisierung einblenden";
	DEFINITION
	{
		WriteCommand(write_op_code);
	}
}

COMMAND read_trans1_ms_lintab_no
{
	/*BLOCK transducer_block_1;
	INDEX 56;*/
	SLOT 1;
	INDEX 144;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			lintab_no
		}
	}
}
COMMAND write_trans1_ms_lintab_no
{
	/*BLOCK transducer_block_1;
	INDEX 144;*/
	SLOT 1;
	INDEX 144;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			lintab_no
		}
		REPLY
		{
		}
	}
}



VARIABLE lintab_level
{
	LABEL		"Linearisierung Fllstand";
	HELP		[trans1_ms_lintab_level_help];
	CLASS		CONTAINED;
	HANDLING
		IF(lintab_edit_mode == 1)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	CONSTANT_UNIT [Percent];
	/*PRE_WRITE_ACTIONS	{
		
		meth_op_code_setzen;
	}*/
}
COMMAND read_trans1_ms_lintab_level
{
	/*BLOCK transducer_block_1;
	INDEX 145;*/
	SLOT 1;
	INDEX 145;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			lintab_volume, lintab_level
		}
	}
}
COMMAND write_trans1_ms_lintab_level
{
	/*BLOCK transducer_block_1;
	INDEX 145;*/
	SLOT 1;
	INDEX 145;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			lintab_volume, lintab_level
		}
		REPLY
		{
		}
	}	
}

VARIABLE lintab_volume
{
	LABEL		"Linearisierung Volumen";
	HELP		[trans1_ms_lintab_volume_help];
	CLASS		CONTAINED;
	HANDLING
		IF(lintab_edit_mode == 1)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	CONSTANT_UNIT [Percent];
}



#define SENSOR_DIAPHRAGM_MATERIALS	\
	DEFAULT_VALUE 253;												\
	{ 1,	[stainless_steel_304], 	[stainless_steel_304_help]	},	\
	{ 2,	[stainless_steel_316],	[stainless_steel_316_help]	},	\
	{ 3,	[hastelloy_c],			[hastelloy_c_help]			},	\
	{ 4,	[monel],				[monel_help]				},	\
	{ 5,	[tantalum],				[tantalum_help]				},	\
	{ 6,	[titanium],				[titanium_help]				},	\
	{10,	"PTFE"												},	\
	{18,	[ceramic],				[ceramic_help]				},	\
	{19, 	[stainless_steel_316l], [stainless_steel_316l_help]	},	\
	{23,	[inconel],				[inconel_help]				},	\
	{253,	[special]											}	\

#define SENSOR_FILL_FLUID	\
	DEFAULT_VALUE 253;												\
	{245,	[silicone_oil]										},	\
	{246,	[vegetable_oil]										},	\
	{247,	[glycerin_H2O]										},	\
	{248,	[inert]												},	\
	{249,	[high_temperature_oil]								},	\
	{253,	[special]											}	\

VARIABLE material_p_plus
{
	LABEL	"Prozessanschlussmaterial";
	HELP	"Das fr den Prozessanschluss verwendete Material.";
	CLASS		CONTAINED;//& DYNAMIC;
	TYPE		ENUMERATED (2)
//	TYPE		ENUMERATED (1)
//	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	2;
		{2,"Edelstahl 1.4404"},
		{3,"Edelstahl 1.4571"},
		{4,"Hastelloy C1"},
		{5,"Edelstahl 1.4435"},
		{6,"Hastelloy C4"},	
		{7,"Hastelloy C22"},
		{8,"PEEK"},
		{9,"Marinebronze Cu SN 12"},
	}
	HANDLING	READ & WRITE;
}
COMMAND read_trans1_ms_material_p_plus
{
	BLOCK transducer_block_1;
	INDEX 26;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			material_p_plus
		}
	}
}
COMMAND write_trans1_ms_material_p_plus
{
	BLOCK transducer_block_1;
	INDEX 26;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			material_p_plus
		}
		REPLY
		{
		}
	}
}

VARIABLE material_p_minus
{
	LABEL	"Prozessanschlusstyp";
	HELP	"Die Art des Prozessanschlusses.";
	CLASS		CONTAINED;// & DYNAMIC;
	TYPE		ENUMERATED (2)
//	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
		{0, "Einschraubgewinde G3/4 Zoll fr Einbaumuffe BEFV-34"},
		{1, "Einschraubgewinde 1,5 Zoll Stahl"},
		{2, "Milchrohranschluss DN50 DIN 11851"},
		{3, "Milchrohranschluss DN40 DIN 11851"},
		{4, "Variventflansch 68mm Durchmesser"},
		{5, "DRD-Anschluss 65m Durchmesser"},
		{6, "Flansch DN25"},
		{7, "Flansch DN40 / PN40"},
		{8, "Flansch DN50 / PN16"},
		{9, "Flansch DN80 / PN16"},
		{10,"Tri-Clamp 2 Zoll ISO 2852"},
		{11,"Nutmutteradapter"},
		{12, "G1/2'' A nach DIN 16288"},
		{13, "G1/2'' A mit Innenbohrung 11 mm"},
		{14, "G1/4 '' A"},
		{15, "G1/2'' B DIN EN ISO288-1 DIN EN 837-3, Manometeranschluss"},
		{16, "G1/2'' B DIN EN ISO288-1 DIN 3852-11 E, frontbndig, mit radialem O-Ring fr Bereiche 0..0,4 bar, 0..1 und -1..0 bar"},
		{17, "G1/4'' B, DIN EN ISO288-1 DIN EN 837-3, Manometeranschluss"},
		{18, "G1 '' B, DIN EN ISO288-1 DIN 3852-11 E, frontbndig, mit radialem O-Ring, EHEDG konform"}	
		{19, "G 1 1/2''frontbndige Membrane"},
		{20, "G3/4''frontbndige Membrane(bis 20 bar) fr Einbaumuffe BEFV-34(nicht fr hochreine Messzelle)"},
		{21, "Milchrohranschluss DN25 DIN 11851"},
		{22, "DRD Flansch DN65"},
		{23, "Flansch DN40, PN10/40, EN1092 (DIN 2527D)"},
		{24, "Flansch DN50, PN10/40, EN1092 (DIN 2527D)"},
		{25, "M2 Lebensmittelrohrverschraubung nach DIN 11851 DN25 PN40"},
		{26, "M4 Lebensmittelrohrverschraubung nach DIN 11851 DN40 PN40"},
		{27, "M5 Lebensmittelrohrverschraubung nach DIN 11851 DN50 PN40"},
		{28, "Tri-Clamp 1''"},
		{29, "Tri-Clamp 1 1/2''"},
		{30, "SMS Verschraubung 1 1/2'' PN40"},
		{31, "SMS Verschraubung 2'' PN40"},
		{32, "G1 Gewinde 1/2 Zoll nach DIN 16288"},
		{33, "G2 Gewinde 3/4 Zoll A"},
		{34, "G3 Gewinde 1 Zoll"},
		{35, "G4 Gewinde 1 1/2 Zoll A"},
		{36, "G5 Gewinde 2 Zoll"},
		{37, "F1 DIN-Flansch DN25 PN64/100"},
		{38, "F3 DIN-Flansch DN40 PN64"},
		{39, "F5 DIN-Flansch DN80 PN10/40"},
		{40, "F6 DIN-Flansch DN100 PN10/16"},
		{41, "R1 Rohrdruckmittler DN25 Milchrohranschluss DIN 11851"},
		{42, "R3 Rohrdruckmittler DN40 Milchrohranschluss DIN 11851"},
		{43, "R4 Rohrdruckmittler DN50 Milchrohranschluss DIN 11851"},
		{44, "R5 Rohrdruckmittler DN65 Milchrohranschluss DIN 11851"},
		{45, "R6 Rohrdruckmittler DN80 Milchrohranschluss DIN 11851"},
		{46, "R7 Rohrdruckmittler DN100 Milchrohranschluss DIN 11851"},
	}
	HANDLING	READ & WRITE;
}
COMMAND read_trans1_ms_material_p_minus
{
	BLOCK transducer_block_1;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			material_p_minus
		}
	}
}
COMMAND write_trans1_ms_material_p_minus
{
	BLOCK transducer_block_1;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			material_p_minus
		}
		REPLY
		{
		}
	}
}

VARIABLE Sensor_Diaphragm_Material
{
	LABEL	"Sensordiaphragmamaterial";
	HELP	"Das Material aus dem die Messzellenmembrane besteht.";
	CLASS		CONTAINED;// & DYNAMIC;
	TYPE		ENUMERATED (2)
//	TYPE		UNSIGNED_INTEGER (2)
	{		
		DEFAULT_VALUE 1;												\
		{1,	"Keramik Al2O3 99,9%"},	\
		{2,	"Stahl 1.4542"},	\
		{3,	"Stahl 1.4571"},	\
		{4,	"Stahl 1.4571"},	\
		{5,	"Stahl 1.4435"},	\
		{6,	"Stahl 1.4435"},	\
		{7,	"Keramik Al2O3 96%"},	\
		{8,	"Keramik Al2O3 96%"},	\
		{9, 	"Stahl 1.4534"}	
	}
	HANDLING	READ & WRITE;
}
COMMAND read_trans1_ms_Sensor_Diaphragm_Material
{
	BLOCK transducer_block_1;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			Sensor_Diaphragm_Material
		}
	}
}
COMMAND write_trans1_ms_Sensor_Diaphragm_Material
{
	BLOCK transducer_block_1;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			Sensor_Diaphragm_Material
		}
		REPLY
		{
		}
	}
}

VARIABLE Sensor_Fill_Fluid
{
	LABEL		"Sensordruckmittlerflssigkeit";
	HELP		"Das als Druckmittler eingesetzte Fllmedium.";
	CLASS		CONTAINED;// & DYNAMIC;
	TYPE		ENUMERATED (2)
//	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE 0;	
	{0,	"kein Druckmittler"}											\
	{1,	"Silikonoel FS20"										},	\
	{2,	"Silikonoel FS100"										},	\
	{3,	"Pflanzenoel FP"										},	\
	{4,	"Lebensmitteloel FD1"												},	\
	{5,	"Hochtemperaturoel FH"								},	\
	{6,	"Synthetisches Oel"											}
	}
	HANDLING	READ & WRITE;
}
COMMAND read_Sensor_Fill_Fluid
{
	BLOCK transducer_block_1;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			Sensor_Fill_Fluid
		}
	}
}
COMMAND write_Sensor_Fill_Fluid
{
	BLOCK transducer_block_1;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			Sensor_Fill_Fluid
		}
		REPLY
		{
		}
	}
}

VARIABLE Sensor_max_static_pressure
{
	LABEL		"Sensorberstdruck";
	HELP		"Der maximale Druck den der Sensor laut Datenblatt noch aushlt ohne zu bersten.";
	CLASS		CONTAINED;// & DYNAMIC;
	TYPE		FLOAT;	
	HANDLING	READ;
	CONSTANT_UNIT	"bar";
}
COMMAND read_Sensor_max_static_pressure
{
	SLOT 1;
	INDEX 75;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			Sensor_max_static_pressure
		}
	}
}

VARIABLE max_sensor_wert
{
	LABEL		"Maximum Sensor Wert";
	HELP		"Der grsste bisher gemessene Sensorwert.";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
}

COMMAND	read_max_sensor_wert
{
	SLOT 1;
	INDEX 97;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			max_sensor_wert
		}
	}
}

COMMAND write_max_sensor_wert
{
	SLOT 1;
	INDEX 97;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			max_sensor_wert
		}
		REPLY
		{
		}
	}
}

VARIABLE min_sensor_wert
{
	LABEL		"Minimum Sensor Wert";
	HELP		"Der kleinste bisher gemessene Sensorwert.";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
}

COMMAND	read_min_sensor_wert
{
	SLOT 1;
	INDEX 98;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			min_sensor_wert
		}
	}
}

COMMAND write_min_sensor_wert
{
	SLOT 1;
	INDEX 98;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			min_sensor_wert
		}
		REPLY
		{
		}
	}
}

VARIABLE sensor_offset
{
	LABEL		"Offset Sensorwert";
	HELP		"Der Offset des Sensorwertes gegenber dem tatschlich anliegenden Druck.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	"bar";
}

COMMAND	read_sensor_offset
{
	SLOT 1;
	INDEX 99;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			sensor_offset
		}
	}
}

COMMAND write_sensor_offset
{
	SLOT 1;
	INDEX 99;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sensor_offset
		}
		REPLY
		{
		}
	}
}

VARIABLE sensor_offset_f
{
	LABEL		"Offset Sensorwert";
	HELP		"Der Offset des Sensorwertes gegenber dem tatschlich anliegenden Druck.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	"bar";
}

COMMAND	read_sensor_offset_f
{
	SLOT 1;
	INDEX 126;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			sensor_offset_f
		}
	}
}

COMMAND write_sensor_offset_f
{
	SLOT 1;
	INDEX 126;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sensor_offset_f
		}
		REPLY
		{
		}
	}
}

VARIABLE sensor_rohwert
{
	LABEL		"Sensorrohwert";
	HELP		"Der unverrechnete und unkorrigierte Sensorwert in bar.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
	CONSTANT_UNIT	"bar";
}

COMMAND	read_sensor_rohwert
{
	SLOT 1;
	INDEX 60;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			sensor_rohwert
		}
	}
}

VARIABLE sensor_einheit
{
	LABEL		"Sensoreinheit";
	HELP		"Die verwendete Grundeinheit des Sensorrohwerts. Diese ist nicht vernderbar, der Sensorrohwert kann aber in andere Einheiten umgerechnet werden.";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	1137;
		{1137, "bar"}
	}
	HANDLING	READ;
}

COMMAND	read_sensor_einheit
{
	SLOT 1;
	INDEX 66;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			sensor_einheit
		}
	}
}

VARIABLE sensor_oring_material
{
	LABEL		"Sensor Dichtungsringmaterial";
	HELP		"Der Offset des Sensorwertes gegenber dem tatschlich anliegenden Druck.";
	CLASS		CONTAINED;
//	TYPE		ENUMERATED (1)
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1;
		{0,"NBR - Nitril-Butadien-Kautschuk"},
		{1,"FPM Fluorelastomer"},//Viton
		{2,"CR"},//Neopren
		{3,"EPDM - Ethylen-Propylen-Dienmonomer fr Lebensmittelanwendungen"},
		{4,"FFKM Perfluorelastomer"},//Kalrez
		{5,"verschweisst (nur bei Druckmittlern)"},		
		{6,"FFKM hochdichte Perfluorelastomer"}		
	}
	HANDLING	READ & WRITE;
}

COMMAND	read_sensor_oring_material
{
	SLOT 1;
	INDEX 76;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			sensor_oring_material
		}
	}
}

COMMAND	write_sensor_oring_material
{
	SLOT 1;
	INDEX 76;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sensor_oring_material
		}
		REPLY
		{
			
		}
	}
}

VARIABLE secondary_value_2_d
{
	LABEL		"Secondary Value 2 Druck";
	HELP		"Der Secondary Value 2 des Druckprofils.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE secondary_status_2_d
{
	LABEL		"Secondary Status 2 Druck";
	HELP		"Der Secondary Status 2 des Druckprofils.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	128;
		{35,  "bad passivated"					 "|de|schlecht! Gert passiviert"},
		{36,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{37,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},	
		{38,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{39,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{60,  "bad local override"				 "|de|schlecht! Ausgabewert lokal vorgegeben"},
		{75,  "uncertain substitute set"		 "|de|unsicher! Ersetzung"},
		{115, "uncertain simulated value"		 "|de|unsicher! simulierter Wert"},
		{116, "uncertain simulated value end"	 "|de|unsicher! Simulation Ende"},
		{120, "uncertain process related"		 "|de|unsicher! prozessbezogen"},
		{128, "Good"							 "|de|Gut"},
		{132, "Good update event"				 "|de|Gut! nderungsereignis"},
		{137, "Good ADVISORY ALARM LOW LIMIT"	 "|de|Gut! Warnmeldung unterer Grenzwert"},
		{138, "Good ADVISORY ALARM HIGH LIMIT"	 "|de|Gut! Warnmeldung oberer Grenzwert"},
		{141, "Good CRITICAL ALARM LOW LIMIT"	 "|de|Gut! Alarmmeldung unterer Grenzwert"},
		{142, "Good CRITICAL ALARM HIGH LIMIT"	 "|de|Gut! Alarmmeldung oberer Grenzwert"},
		{164, "Good maintenance request"		 "|de|Gut! Wartungsanfrage"}		
	}
	HANDLING	READ;
}

COMMAND read_secondary_value_2_d
{
	SLOT 1;
	INDEX 83;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			secondary_value_2_d, secondary_status_2_d
		}
	}
}

VARIABLE secondary_value_1_d
{
	LABEL		"Secondary Value 1 Druck";
	HELP		"Der Secondary Value 1 des Druckprofils.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}
	
VARIABLE secondary_status_1_d
{
	LABEL		"Secondary Status 1 Druck";
	HELP		"Der Secondary Status 1 des Druckprofils.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	128;
		{35,  "bad passivated"					 "|de|schlecht! Gert passiviert"},
		{36,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{37,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},	
		{38,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{39,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{60,  "bad local override"				 "|de|schlecht! Ausgabewert lokal vorgegeben"},
		{75,  "uncertain substitute set"		 "|de|unsicher! Ersetzung"},
		{115, "uncertain simulated value"		 "|de|unsicher! simulierter Wert"},
		{116, "uncertain simulated value end"	 "|de|unsicher! Simulation Ende"},
		{120, "uncertain process related"		 "|de|unsicher! prozessbezogen"},
		{128, "Good"							 "|de|Gut"},
		{132, "Good update event"				 "|de|Gut! nderungsereignis"},
		{137, "Good ADVISORY ALARM LOW LIMIT"	 "|de|Gut! Warnmeldung unterer Grenzwert"},
		{138, "Good ADVISORY ALARM HIGH LIMIT"	 "|de|Gut! Warnmeldung oberer Grenzwert"},
		{141, "Good CRITICAL ALARM LOW LIMIT"	 "|de|Gut! Alarmmeldung unterer Grenzwert"},
		{142, "Good CRITICAL ALARM HIGH LIMIT"	 "|de|Gut! Alarmmeldung oberer Grenzwert"},
		{164, "Good maintenance request"		 "|de|Gut! Wartungsanfrage"}		
	}
	HANDLING	READ;
}

COMMAND read_secondary_value_1_d
{
	SLOT 1;
	INDEX 81;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			secondary_value_1_d, secondary_status_1_d
		}
	}
}

VARIABLE primary_value_druck
{
	LABEL		"Primary Value Druck";
	HELP		"Der Primary Value des Druckprofils.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE primary_status_d
{
	LABEL		"Primary Status Druck";
	HELP		"Der Primary Status des Druckprofils.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	128;
		{35,  "bad passivated"					 "|de|schlecht! Gert passiviert"},
		{36,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{37,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},	
		{38,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{39,  "bad maintenance alarm"			 "|de|schlecht! Wartungssalarm"},
		{60,  "bad local override"				 "|de|schlecht! Ausgabewert lokal vorgegeben"},
		{75,  "uncertain substitute set"		 "|de|unsicher! Ersetzung"},
		{115, "uncertain simulated value"		 "|de|unsicher! simulierter Wert"},
		{116, "uncertain simulated value end"	 "|de|unsicher! Simulation Ende"},
		{120, "uncertain process related"		 "|de|unsicher! prozessbezogen"},
		{128, "Good"							 "|de|Gut"},
		{132, "Good update event"				 "|de|Gut! nderungsereignis"},
		{137, "Good ADVISORY ALARM LOW LIMIT"	 "|de|Gut! Warnmeldung unterer Grenzwert"},
		{138, "Good ADVISORY ALARM HIGH LIMIT"	 "|de|Gut! Warnmeldung oberer Grenzwert"},
		{141, "Good CRITICAL ALARM LOW LIMIT"	 "|de|Gut! Alarmmeldung unterer Grenzwert"},
		{142, "Good CRITICAL ALARM HIGH LIMIT"	 "|de|Gut! Alarmmeldung oberer Grenzwert"},
		{164, "Good maintenance request"		 "|de|Gut! Wartungsanfrage"}		
	}
	HANDLING	READ;
}

COMMAND read_primary_value_druck
{
	SLOT 1;
	INDEX 70;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			primary_value_druck, primary_status_d
		}
	}
}

/********************************************************/
/*	Fllstandsprofil				*/
/*							*/
/********************************************************/

VARIABLE trans2_st_rev
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

COMMAND read_trans2_st_rev
{
	SLOT 1;
	INDEX 109;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_st_rev
		}
	}
}

VARIABLE cal_type
{
	LABEL		"Nass-/Trockenabgleich";
	HELP		"Bei der Konfiguration Nassabgleich wird bei der bertragung der Werte fr die Kalibrierpunkte Cal_Point_LO bzw. Cal_Point_Hi der anliegende Messwert als Sensorwerte bernommen.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{0,"Trockenabgleich"},
		{1,"Nassabgleich"},
	}
	HANDLING	READ & WRITE;
}

COMMAND read_cal_type
{
	SLOT 1;
	INDEX 127;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			cal_type
		}
	}
}

COMMAND write_cal_type
{
	SLOT 1;
	INDEX 127;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			cal_type
		}
		REPLY
		{
			
		}
	}
}

VARIABLE level_oben
{
	LABEL		"Fllstand oben";
	HELP		"Der Fllstand am oberen Endpunkt des Messbereiches.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
	}
	HANDLING	READ & WRITE;
}

COMMAND read_level_oben
{
	SLOT 1;
	INDEX 131;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			level_oben
		}
	}
}

COMMAND write_level_oben
{
	SLOT 1;
	INDEX 131;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			level_oben
		}
		REPLY
		{
			
		}
	}
}

VARIABLE level_unten
{
	LABEL		"Fllstand unten";
	HELP		"Der Fllstand beim Nullpunkt des Messbereiches.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

COMMAND read_level_unten
{
	SLOT 1;
	INDEX 130;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			level_unten
		}
	}
}

COMMAND write_level_unten
{
	SLOT 1;
	INDEX 130;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			level_unten
		}
		REPLY
		{
			
		}
	}
}	

VARIABLE level_offset
{
	LABEL		"Fllstand Offset";
	HELP		"Mit diesem Parameter knnen Offsets in der Einbaulage ausgeglichen werden.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

COMMAND read_level_offset
{
	SLOT 1;
	INDEX 132;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			level_offset
		}
	}
}

COMMAND write_level_offset
{
	SLOT 1;
	INDEX 132;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			level_offset
		}
		REPLY
		{
			
		}
	}
}			

VARIABLE secondary_value_2_f
{
	LABEL		"Secondary Value 2 Fllstand";
	HELP		"Der Secondary Value 2 des Fllstandsprofils.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE secondary_status_2_f
{
	LABEL		"Secondary Status 2 Fllstand";
	HELP		"Der Secondary Status 2 des Fllstandprofils.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{0,"test_0"},
		{1,"test_1"}
	}
	HANDLING	READ;
}

COMMAND read_secondary_value_2_f
{
	SLOT 1;
	INDEX 124;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			secondary_value_2_f, secondary_status_2_f
		}
	}
}

VARIABLE secondary_value_1_f
{
	LABEL		"Secondary Value 1 Fllstand";
	HELP		"Der Secondary Value 1 des Fllstandsprofils.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE secondary_status_1_f
{
	LABEL		"Secondary Status 1 Fllstand";
	HELP		"Der Secondary Status 1 des Fllstandprofils.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{0,"test_0"},
		{1,"test_1"}
	}
	HANDLING	READ;
}

COMMAND read_secondary_value_1_f
{
	SLOT 1;
	INDEX 122;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			secondary_value_1_f, secondary_status_1_f
		}
	}
}

VARIABLE primary_value_fuellstand
{
	LABEL		"Primary Value Fllstand";
	HELP		"Der Primary Value des Fllstandsprofils.";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE primary_status_1_f
{
	LABEL		"Primary Status 1 Fllstand";
	HELP		"Der Primary Status des Fllstandprofils.";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	128;
		{35, "schlecht! Gert passiviert"},
		{36, "schlecht! Wartungssalarm"},
		{37, "schlecht! Wartungssalarm"},	
		{38, "schlecht! Wartungssalarm"},
		{39, "schlecht! Wartungssalarm"},
		{60, "schlecht! Ausgabewert lokal vorgegeben"},
		{75, "unsicher! Ersetzung"},
		{115, "unsicher! simulierter Wert"},
		{116, "unsicher! Simulation Ende"},
		{120, "unsicher! prozessbezogen"},
		{128, "Gut"},
		{132, "Gut! nderungsereignis"},
		{137, "Gut! Warnmeldung unterer Grenzwert"},
		{138, "Gut! Warnmeldung oberer Grenzwert"},
		{141, "Gut! Alarmmeldung unterer Grenzwert"},
		{142, "Gut! Alarmmeldung oberer Grenzwert"},
		{164, "Gut! Wartungsanfrage"}
	}
	HANDLING	READ;
}

COMMAND read_primary_value_fuellstand
{
	SLOT 1;
	INDEX 116;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			primary_value_fuellstand, primary_status_1_f
		}
	}
}

/* ----------------------------------------------------------------
 *	   AI-Function Block
 * ----------------------------------------------------------------
 */

 //define FUNC1_TITLE
#define DECIMAL_POINT_7_SUPPORTED
#define DECIMAL_POINT_STANDARD_SUPPORTED
//#define FUNC1_PV_UNIT_LIST     DEF_TRANS_PRIMARY_VALUE_UNIT_20
#define DEFAULT_VALUE_func1_lo_lim -3e38
#define DEFAULT_VALUE_func1_lo_lo_lim -3e38
#define DEFAULT_VALUE_func1_hi_lim 3e38
#define DEFAULT_VALUE_func1_hi_hi_lim 3e38
#define DEFAULT_VALUE_func1_lower_range_value -3e38
#include "SIPASTAI1_200.inc"
/*REFRESH primary_value_conditions
{
	trans1_primary_value_unit,
	trans1_primary_value_decimal:

	func1_pv_upper_range_value,
	func1_pv_lower_range_value
}*/

VARIABLE func1_out_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		}
	}
	HANDLING	READ & WRITE;
}


REFRESH out_value_conditions
{
	func1_out_unit,
	func1_out_decimal_point:

	func1_out_upper_range_value,
	func1_out_lower_range_value,
	func1_alarm_hys,
	func1_hi_hi_lim,
	func1_hi_lim,
	func1_lo_lim,
	func1_lo_lo_lim
}

VARIABLE out_value
{
	LABEL		"Ausgabewert";
	HELP		"";
	CLASS		DYNAMIC;
	TYPE		FLOAT;	
	HANDLING	READ;
}

VARIABLE out_status
{
	LABEL		"Ausgabestatus";
	HELP		"";
	CLASS		DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	128;
		{35, "schlecht! Gert passiviert"},
		{36, "schlecht! Wartungssalarm"},
		{37, "schlecht! Wartungssalarm"},	
		{38, "schlecht! Wartungssalarm"},
		{39, "schlecht! Wartungssalarm"},
		{60, "schlecht! Ausgabewert lokal vorgegeben"},
		{68, "unsicher! letzter brauchbarer Wert"},
		{75, "unsicher! Ersetzung"},
		{115, "unsicher! simulierter Wert"},
		{116, "unsicher! Simulation Ende"},
		{120, "unsicher! prozessbezogen"},
		{128, "Gut"},
		{132, "Gut! nderungsereignis"},
		{137, "Gut! Warnmeldung unterer Grenzwert"},
		{138, "Gut! Warnmeldung oberer Grenzwert"},
		{141, "Gut! Alarmmeldung unterer Grenzwert"},
		{142, "Gut! Alarmmeldung oberer Grenzwert"},
		{164, "Gut! Wartungsanfrage"},
		{165, "Gut! Wartungsanfrage"},
		{166, "Gut! Wartungsanfrage"}
	}
	HANDLING	READ;
}

COMMAND read_out_value
{
	SLOT 1;
	INDEX 26;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			out_value, out_status
		}
	}
}

VARIABLE AI_Targetmodus		//optional
{
	LABEL		"AI Zielmodus";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	8;
		{ 8,		"automatisch"		},
		{ 16,		"manuell"	},
		{ 128, 		"Messbetrieb ausgesetzt" },		
	}
	HANDLING	READ & WRITE;
}

COMMAND read_AI_Targetmodus
	{
		SLOT 1;
		INDEX 21;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				AI_Targetmodus
			}
		}
	}

COMMAND write_AI_Targetmodus
	{
		SLOT 1;
		INDEX 21;
		OPERATION WRITE;
		TRANSACTION
		{
			REQUEST
			{
				AI_Targetmodus
			}
			REPLY
			{
			}
		}
	}

VARIABLE func1_blk_profile_rev
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		{	769,	"3.01"	}
	}
	HANDLING	READ;
}

VARIABLE AI_Modus		//optional
{
	LABEL		"Modus";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	8;
		{ 8,		"automatisch"		},
		{ 16,		"manuell"	},
		{ 128, 		"Messbetrieb ausgesetzt" },
				
	}
	HANDLING	READ;
}

COMMAND read_AI_Modus
	{
		SLOT 1;
		INDEX 22;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				AI_Modus
			}
		}
	}



VARIABLE func1_out_unit
{
	LABEL		[func_out_scale_unit];
	HELP		[func_out_scale_unit_help];
	CLASS		CONTAINED & SERVICE;
	TYPE		ENUMERATED (2)
	{
//		DEFAULT_VALUE	1137;
		DEFAULT_VALUE	IF(channel == 326)
				{
					1137;
				}
				ELSE	
				{
					1010;
				}

		IF(channel == 326)
		{
			{1137, "bar", [bar_help]},
			{1133, "kPa", [kPa_help]},		
			{1138,"mbar", [mbar_help]},
			{1141, "PSI", [psi_help]},
		}
		ELSE
		{
			{ 1342,  "%",				[Percent_help]		},	
			{ 1010,  "meter", 				[meter_help]		},	
			{ 1018,  "ft",					[ft_help]			},	
		}
		
		
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_out_upper_range_value
{
	LABEL		[func_out_scale_upper_value];
	HELP		[func_out_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100 ;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_out_lower_range_value
{
	LABEL		[func_out_scale_lower_value];
	HELP		[func_out_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0 ;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
}


VARIABLE pv_unit
{
	LABEL		"Einheit";
	HELP		[func_pv_scale_unit_help];
	CLASS		CONTAINED ;
	TYPE		ENUMERATED (2)
	{		
			DEFAULT_VALUE	1137;			
			{1137, "bar", [bar_help]},
			{1133, "kPa", [kPa_help]},		
			{1138,"mbar", [mbar_help]},
			{1141, "PSI", [psi_help]}
		
	}
	HANDLING	READ & WRITE;
}

VARIABLE pv_f_unit
{
	LABEL		"Einheit";
	HELP		"Einheit des Fllstands";
	CLASS		CONTAINED ;
	TYPE		ENUMERATED (2)
	{		
			DEFAULT_VALUE	1010;			
			{ 1342,  "%",				[Percent_help]		},	
			{ 1010,  "meter", 				[meter_help]		},	
			{ 1018,  "ft",					[ft_help]			},
		
	}
	HANDLING	READ & WRITE;
}

VARIABLE pv_upper_range_value
{
	LABEL		[func_pv_scale_upper_value];
	HELP		[func_pv_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE  	1.0 ;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
}

VARIABLE pv_lower_range_value
{
	LABEL		[func_pv_scale_lower_value];
	HELP		[func_pv_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE  0.0;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}

	HANDLING	READ & WRITE;
}
COMMAND read_func1_pv_scale
{
	SLOT 1;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			pv_upper_range_value, pv_lower_range_value		
		}
	}
}

COMMAND write_func1_pv_scale
{
	SLOT 1;
	INDEX 27;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pv_upper_range_value, pv_lower_range_value			
		}
		REPLY
		{
		}
	}
}


VARIABLE failsafe_wert
{
	LABEL		"Fehlerersatzwert";
	HELP		"Im Falle eines Fehlers des Sensors kann statt des fehlerhaften Sensorwertes dieser hier festgelegte Ersatzwert ausgegeben werden.";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE		nennnullpunkt;
		MAX_VALUE		nennendpunkt;
		
	}
	HANDLING	READ & WRITE;
}

COMMAND read_failsafe_wert
{
	SLOT 1;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			failsafe_wert
		}
	}
}

COMMAND write_failsafe_wert
{
	SLOT 1;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			failsafe_wert
		}
		REPLY
		{
		}
	}
}

VARIABLE failsafe_type
{
	LABEL		"Fehlerverhalten";
	HELP		"Im Falle eines Fehlers wird hier festgelegt, wie sich das Gert verhalten soll.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{0,"Ausgabe Fehlerersatzwert",""},
		{1,"Ausgabe letzter nutzbarer Messwert",""},
		{2,"Ausgabe des gemessenen schlechten Messwertes",""}
		
	}
	HANDLING	READ & WRITE;
}

COMMAND read_failsafe_type
{
	SLOT 1;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			failsafe_type
		}
	}
}

COMMAND write_failsafe_type
{
	SLOT 1;
	INDEX 33;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			failsafe_type
		}
		REPLY
		{
		}
	}
}

MENU Tab_s_func1_pv_range
{
	LABEL		[menu_input_measwindow];
	ITEMS
	{
		IF(channel == 326)
		{
			pv_unit
		}
		ELSE
		{
			pv_f_unit
		}
		pv_lower_range_value,	
		pv_upper_range_value	
	}
}

MENU Tab_m_func1_pv_range
{
	LABEL		[menu_input_measwindow];
	ITEMS
	{
		IF(channel == 326)
		{
			pv_unit				(READ_ONLY)
		}
		ELSE
		{
			pv_f_unit			(READ_ONLY)
		}
		pv_lower_range_value	(READ_ONLY)	,	
		pv_upper_range_value	(READ_ONLY)	
	}
}


// redefined func1_out_value and func1_out_status:
// modifications of func1_out_value are possible in MAN-mode of the block
VARIABLE func1_out_value
{
	LABEL		[func_out_value];
	HELP		[func_ai_out_value_help];
	CLASS		OUTPUT & DYNAMIC;
	TYPE		FLOAT
	{
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING
		IF(func1_target_mode == 0x10)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}

VARIABLE op_code_1
{
	LABEL	"Lade Tabelle";
	HELP	"";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{1,"Laden der Wertepaare"}
		{3,"bernehmen der geladenen Wertepaare"}
	}
	HANDLING READ & WRITE;	
}

VARIABLE op_code_3
{
	LABEL	"op_code";
	HELP	"";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (1)
	{
		DEFAULT_VALUE	3;
		{0,"test_0"},
		{3,"test_3"}
	}
	HANDLING READ & WRITE;
}
 
VARIABLE channel 
{
	LABEL	"verwendetes Profil";
	HELP	"Das ber den channel-Parameter eingestellte Profil des Gertes.";
	CLASS	CONTAINED;
	TYPE		ENUMERATED (2)
//	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	326;
		{326,"Druck","Es wird das Druckprofil verwendet."},
		{628,"Fuellstand","Es wird das Fllstandsprofil verwendet."}
	}
	HANDLING READ & WRITE;
	POST_EDIT_ACTIONS
	{
		meth_post_edit_channel
	}
}

METHOD meth_post_edit_channel
{
	LABEL "meth_pre_edit_channel";
	DEFINITION
	{
		if (channel == 326)
		{
//			ACKNOWLEDGE("if (channel == 326)");
			func1_out_unit = 1137;
		}
		else
		{
//			ACKNOWLEDGE("else (channel == 628)");
			func1_out_unit = 1010;
		}
	}
}


COMMAND read_channel
{
	SLOT 1;
	INDEX 30;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
			
		}
		REPLY
		{
			channel
		}
	}
}
COMMAND write_channel
{
	SLOT 1;
	INDEX 30;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			channel
		}
		REPLY
		{
			
		}
	}
}

VARIABLE func1_out_status
{
	LABEL		[func_out_status];
	HELP		[func_out_status_help];
	CLASS		OUTPUT & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	128;
		{35, "schlecht! Gert passiviert"},
		{36, "schlecht! Wartungssalarm"},
		{37, "schlecht! Wartungssalarm"},	
		{38, "schlecht! Wartungssalarm"},
		{39, "schlecht! Wartungssalarm"},
		{60, "schlecht! Ausgabewert lokal vorgegeben"},
		{68, "schlecht! Letzter brauchbarer Wert"},	
		{75, "unsicher! Ersetzung"},
		{115, "unsicher! simulierter Wert"},
		{116, "unsicher! Simulation Ende"},
		{120, "unsicher! prozessbezogen"},
		{128, "Gut"},
		{132, "Gut! nderungsereignis"},
		{137, "Gut! Warnmeldung unterer Grenzwert"},
		{138, "Gut! Warnmeldung oberer Grenzwert"},
		{141, "Gut! Alarmmeldung unterer Grenzwert"},
		{142, "Gut! Alarmmeldung oberer Grenzwert"},
		{164, "Gut! Wartungsanfrage"},
		{165, "Gut! Wartungsanfrage"},
		{166, "Gut! Wartungsanfrage"},	
		
	}
	HANDLING
		IF(func1_target_mode == 0x10)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}

COMMAND read_func1_out
{
	BLOCK function_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_out_value, func1_out_status
		}
	}
}

COMMAND write_func1_out
{
	BLOCK function_block_1;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_out_value, func1_out_status
		}
		REPLY
		{
		}
	}
}


VARIABLE simulation_enabled
{
	LABEL		"Simulation";
	HELP		"Aktiviert bzw. deaktiviert die Simulation des Ausgabewertes.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{0, "gesperrt"},
		{1, "freigegeben"}
	}
	HANDLING READ & WRITE;	
}

VARIABLE simulation_wert
{
	LABEL		"Simulationswert";
	HELP		"Der Wert der fr den Ausgabewert vorgegeben werden soll.";
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING READ & WRITE;	
}

VARIABLE simulation_status
{
	LABEL		"Simulationsstatus";
	HELP		"Status des simulierten Wertes des Ausgabewertes.";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	128;
		{35, "schlecht! Gert passiviert"},
		{36, "schlecht! Wartungssalarm"},
		{37, "schlecht! Wartungssalarm"},	
		{38, "schlecht! Wartungssalarm"},
		{39, "schlecht! Wartungssalarm"},
		{60, "schlecht! Ausgabewert lokal vorgegeben"},
		{75, "unsicher! Ersetzung"},
		{115, "unsicher! simulierter Wert"},
		{116, "unsicher! Simulation Ende"},
		{120, "unsicher! prozessbezogen"},
		{128, "Gut"},
		{132, "Gut! nderungsereignis"},
		{137, "Gut! Warnmeldung unterer Grenzwert"},
		{138, "Gut! Warnmeldung oberer Grenzwert"},
		{141, "Gut! Alarmmeldung unterer Grenzwert"},
		{142, "Gut! Alarmmeldung oberer Grenzwert"},
		{164, "Gut! Wartungsanfrage"}
	}
	HANDLING READ & WRITE;	
}

COMMAND read_func1_simulation
{
	SLOT 1;
	INDEX 50;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			simulation_status, simulation_wert, simulation_enabled
		}
	}
}

COMMAND write_func1_simulation
{
	SLOT 1;
	INDEX 50;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			simulation_status, simulation_wert, simulation_enabled
		}
		REPLY
		{
		}
	}
}

// AI function block objects have not the PROFIBUS-PA Profile 2.0 mapping
// in firmware V1.0


/* ================================================================
 *	   Kommunikationsfehler
 * ================================================================
 */
/*	#include "SIPAST_CommError.inc"		*/


/*******************************************************************************/
/*****	MENU Bar  **************************************************************/
/*******************************************************************************/
#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"


MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{		
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_Options,
		Menu_Help2
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_M_View,
		Menu_M_Options,
		Menu_Help2
	}
}


/*---------------------------------------------------------------------*/
/*	  Menu: Device													   */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,
		std_LoadinPC,
		SEPARATOR,
		OnlineDialog_simulation,
		OnlineDialog_reset,
		OnlineDialog_wartungsintervall
		IF(channel == 628)
		{
		SEPARATOR,
		OnlineDialog_linearization
		}
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,
		std_LoadinPC
	}
}

METHOD method_set
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
	}
}

METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}

/*---------------------------------------------------------------------*/
/*	  Menu: View													   */
/*---------------------------------------------------------------------*/

MENU Menu_S_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		OnlineWindow_diagnosis,
		SEPARATOR,
		OnlineWindow_s_indicators,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

MENU Menu_M_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		OnlineWindow_diagnosis,
		SEPARATOR,
		OnlineWindow_m_indicators,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

MENU Menu_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		OnlineWindow_S_alarm_func1,
	}
}


METHOD std_Funktionsleiste
{
	LABEL		[menu_View_Toolbar];
	DEFINITION
	{
	}
}

METHOD std_Statuszeile
{
	LABEL		[menu_View_Statusbar];
	DEFINITION
	{
	}
}

METHOD std_Update
{
	LABEL		[menu_View_Update];
	DEFINITION
	{
	}
}

/*---------------------------------------------------------------------*/
/*	  Menu: Help													   */
/*---------------------------------------------------------------------*/


MENU Menu_Help2
{
	LABEL		[menu_Help];
	ITEMS
	{
			std_Hilfethemen,
			std_HilfeKontext,
			SEPARATOR,
			std_HilfeGeraet,
#ifdef DEVICE_MANUAL_FILENAME
			methodOpenDeviceManual,
#endif

			SEPARATOR,
			std_Hilfebenutzen,
			std_Info
	}
}



#ifdef DEVICE_MANUAL_FILENAME
METHOD methodOpenDeviceManual
{
	LABEL [menu_DeviceManual] ;
	ACCESS OFFLINE ;
	DEFINITION
	{
		ShellExecute(DEVICE_MANUAL_FILENAME) ;
	}
}
#endif


/*******************************************************************************/
/*****	Online-Windows	********************************************************/
/*******************************************************************************/

MENU OnlineWindow_display
{
	LABEL		"Messung";//[menu_dialog_display];
	ITEMS
	{
		Page_func1_out_display//,
	//	Page_display_measure,
	}
}
MENU Page_func1_out_display
{
	LABEL		"Function Block 1 - Analog Input" ;
	ITEMS
	{
		channel			(HIDDEN),
		BarVal_func1_out_display,
		Group_display_func1_out,
		Group_display_func1_in
	}
}

MENU Page_display_measure
{
	LABEL		[menu_dialog_display_measure];
	ITEMS
	{
		Group_primary,
		Val_trans1_sensor_value,

 		Group_sensor_display
	}
}

MENU BarVal_func1_out_display
{
	LABEL		[func_out_value];
	ITEMS
	{
		func1_out_value,
		func1_out_lower_range_value 	(READ_ONLY),
		func1_out_upper_range_value	(READ_ONLY)
	}
}


MENU Group_display_func1_out
{
	LABEL		[menu_dialog_display_output] ;
	ITEMS
	{
		AI_Modus,
		SEPARATOR,
		func1_out_status	(READ_ONLY),
		//func1_current_state_alarm_sum
	}
}


MENU Group_primary
{
	LABEL		"Messwert";//[trans_value];
	ITEMS
	{
		IF(channel == 326)
		{
			primary_value_druck,//trans1_primary_value,  
			SEPARATOR,
			primary_status_d,
		}
		ELSE
		{
			primary_value_fuellstand,
			SEPARATOR,
			primary_status_1_f,
		}
	}
}

MENU Val_trans1_sensor_value
{
	LABEL "Sensordruck" ;
	ITEMS
	{
		trans1_sensor_value	(READ_ONLY)
	}
}


MENU Group_sensor_display
{
	LABEL		"Sensordruck";//[trans_pres_sensor_value];
	ITEMS
	{
		trans1_sensor_value,
		sensor_low_limit		(READ_ONLY),
		sensor_high_limit		(READ_ONLY)
	}
}

MENU Group_display_primary
{
	LABEL		[std_V0H0];//[trans_value];
	ITEMS
	{
		trans1_actual_mode		(READ_ONLY),
		trans1_primary_status	(READ_ONLY),
		trans1_current_state_alarm_sum
	}
}

MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_general,
		Page_diagnosis_phys_block,     //see SIPASTPB_200.inc
		Page_diagnosis_trans_block,
		Page_diagnosis_func1
	}
}

MENU Page_diagnosis_general
{
	LABEL		[menu_dialog_general];
	ITEMS
	{
		phys_tag_desc			(READ_ONLY),
		phys_manufacturer_id,
		device_id,
		phys_serial_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date		(READ_ONLY),
		wartungsintervall		(READ_ONLY),
		phys_diagnosis,
		// manufacturer code:
		/*phys_ms_matrix_err_code,
		phys_ms_matrix_last_err_code(READ_ONLY)*/
	}
}

MENU Page_diagnosis_phys_block
{
	LABEL		[blk_block_object_PHYSICAL];
	ITEMS
	{
		phys_blk_object,
		phys_blk_parent_class,
		phys_blk_class,
		/*phys_blk_dd_reference,
		phys_blk_dd_rev,
		phys_blk_profile,*/
		phys_blk_profile_rev,
		phys_st_rev,
		phys_actual_mode
	}
}

MENU Page_diagnosis_trans_block
{
	LABEL		[blk_block_object_TRANSDUCER];
	ITEMS
	{
		IF(channel == 326)
		{
		trans1_blk_object,
		trans1_blk_parent_class,
		trans1_blk_class,
		/*trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,*/
		trans1_blk_profile_rev,
		trans1_st_rev,
		trans1_actual_mode
		}
		ELSE
		{
			trans2_blk_object,
			trans2_blk_parent_class,
			trans2_blk_class,
		/*trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,*/
			trans2_blk_profile_rev,
			trans2_st_rev,
			trans2_actual_mode
		}
	}
}

MENU Page_diagnosis_func1
{
	LABEL		FUNC1_TITLE ;
	ITEMS
	{
		func1_blk_object,
		func1_blk_parent_class,
		func1_blk_class,
		func1_blk_profile_rev,
		func1_st_rev,
		func1_actual_mode,
		func1_simulation_enabled(READ_ONLY)
	}
}

MENU OnlineWindow_s_indicators
{
	LABEL		[menu_indicator];
	ITEMS
	{
		Page_s_pressure_pointer
	}
}

MENU OnlineWindow_m_indicators
{
	LABEL		[menu_indicator];
	ITEMS
	{
		Page_m_pressure_pointer
	}
}

MENU Page_s_pressure_pointer
{
	LABEL		[menu_pres_indicator];
	ITEMS
	{
		max_sensor_wert (READ_ONLY),
		min_sensor_wert (READ_ONLY),
		meth_reset_pressure
	}
}
MENU Page_m_pressure_pointer
{
	LABEL		[menu_pres_indicator];
	ITEMS
	{
		max_sensor_wert (READ_ONLY),
		min_sensor_wert (READ_ONLY)		
	}
}

/*******************************************************************************/
/*****	Online-Dialogs	********************************************************/
/*******************************************************************************/

MENU OnlineDialog_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		simulation_input_func1,
		Page_simulation_output_func1
	}
}

MENU simulation_input_func1
{
	LABEL		[menu_dialog_simulation_input];
	ITEMS
	{
		simulation_enabled,
		Group_simulate_input_func1,
		method_set
	}
}

MENU Group_simulate_input_func1
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func1_channel (HIDDEN),
		simulation_wert,
		SEPARATOR,
		simulation_status
	}
}

MENU Page_simulation_output_func1
{
	LABEL		[menu_dialog_simulation_output];
	ITEMS
	{
		func1_target_mode,
		func1_actual_mode,
		Group_simulate_output_func1,
		method_set
	}
}

MENU Group_simulate_output_func1
{
	LABEL		[func_out_value];
	ITEMS
	{
		func1_out_value,
		SEPARATOR,
		func1_out_status
	}
}

MENU OnlineDialog_reset
{
	LABEL		[master_reset];
	HELP		[master_reset_help];
	ITEMS
	{
		phys_factory_reset,
		phys_diagnosis,
		method_set
	}
}

MENU OnlineDialog_wartungsintervall
{
	LABEL		"Wartungsintervall";
	ITEMS
	{
		wartungsintervall,
		meth_wartungsintervallschreiben,	
		wartungstimer (READ_ONLY)	
		
	}
}



/*---------------------------------------------------------------------*/
/*	  OnlineDialog: Linearization									   */
/*---------------------------------------------------------------------*/

MENU OnlineDialog_linearization
{
	LABEL	"Linearisierung";
	ACCESS	OFFLINE;
	ITEMS
	{
		menu_linearize
		
	}
}

MENU menu_linearize
{
	LABEL	"Laden und Lesen der Linearisierungspunkte";
	ITEMS
	{		
		lintab_edit_mode	,
		lintab_no,	
		lintab_level	,		//V3H8
		lintab_volume ,		//V3H9
		meth_write_lin_value,
		meth_read_lin_value
	}
}




/** ----------------------------------------------------------------
  *    Table: Specialist
  * ----------------------------------------------------------------
  */

MENU Table_Main_Specialist
{
	LABEL	"Hydrocont S";//DEFAULT_VALUE_phys_device_id ;
	ITEMS
	{
		channel,
		Tab_s_PA_Profil
	}
}

MENU Table_Main_Maintenance
{
	LABEL	"Hydrocont S";//DEFAULT_VALUE_phys_device_id ;
	ITEMS
	{
		channel			(READ_ONLY),
		//Tab_s_PA_Profil
		Tab_m_PA_Profil
	}
}

MENU Tab_s_PA_Profil
{
	LABEL	"Druckmessgert";//[menu_table_sensor_pressure];
	ITEMS
	{
		Tab_s_ident,               // see SIPASTPB_200.inc
		Tab_s_input,
		Tab_s_output,
		Tab_s_const,
		Tab_s_interface,
		Tab_s_certificates        // see SIPASTPB_200.inc
	}
}

MENU Tab_s_ident
{
	LABEL		[menu_ident];
	ITEMS
	{
		Tab_s_ident_opunit,
		Tab_s_ident_device
	}
	PRE_READ_ACTIONS  
	{
		meth_channel_reading
	}
}

MENU Tab_s_ident_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
#ifdef EXTRA_ITEMS_TAB_S_IDENT_DEVICE
		EXTRA_ITEMS_TAB_S_IDENT_DEVICE
#endif
		phys_manufacturer_id,
		device_id,
		phys_serial_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_blk_profile_rev,
		phys_install_date,
		phys_st_rev,
		wartungsintervall,
		wartungstimer (READ_ONLY),
		ueberlastzaehler,
		nennnullpunkt			(READ_ONLY),
		nennendpunkt			(READ_ONLY),
		Targetmodus	
#ifdef PHYS_ADDITIONAL_PARAMETER
		,
		PHYS_ADDITIONAL_PARAMETER
#endif

	}
}
MENU Tab_m_ident_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
#ifdef EXTRA_ITEMS_TAB_S_IDENT_DEVICE
		EXTRA_ITEMS_TAB_S_IDENT_DEVICE
#endif
		phys_manufacturer_id,
		device_id,
		phys_serial_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_blk_profile_rev,
		phys_install_date		(READ_ONLY),
		phys_st_rev,
		wartungsintervall		(READ_ONLY),
		wartungstimer			(READ_ONLY),
		ueberlastzaehler		(READ_ONLY),
		nennnullpunkt			(READ_ONLY),
		nennendpunkt			(READ_ONLY),
		Targetmodus				(READ_ONLY),
#ifdef PHYS_ADDITIONAL_PARAMETER
		,
		PHYS_ADDITIONAL_PARAMETER
#endif

	}
}

MENU Tab_m_PA_Profil
{
	LABEL		[menu_table_sensor_pressure];
	ITEMS
	{
		Tab_m_ident,          //see SIPASTPB_200.inc
		Tab_m_input,
		Tab_m_output,
		Tab_m_const,
		Tab_m_interface,
		Tab_m_certificates
	}
}

MENU Tab_s_input
{
	LABEL		[menu_input];
	ITEMS
	{
		IF(channel == 326)
		{
			Tab_s_trans1
		}
		ELSE
		{
			Tab_s_trans2
		}
	}
}

MENU Tab_s_trans1
{
	LABEL		"Transducer Block Druck";
	ITEMS
	{
		trans1_st_rev,
		trans1_primary_value_type,

		Tab_s_trans1_input_meassurelimit,
		Tab_s_trans1_max_min_wert		
	}
}

MENU Tab_m_trans1
{
	LABEL		"Transducer Block Druck";
	ITEMS
	{
		trans1_st_rev,
		trans1_primary_value_type,

		Tab_m_trans1_input_meassurelimit,
		Tab_m_trans1_max_min_wert		
	}
}

MENU Tab_s_trans2
{
	LABEL		"Transducer Block Fllstand";
	ITEMS
	{
		trans2_st_rev,
		cal_type,
		
		Tab_s_trans1_input_meassurelimit,
		Tab_s_input_table,
		Tab_s_trans1_max_min_wert,
		Tab_s_trans2_fuellstand,
	}
}

MENU Tab_s_trans1_max_min_wert
{
	LABEL		"Max_Min_Werte";
	ITEMS
	{
		max_sensor_wert,
		min_sensor_wert		
	}
}
MENU Tab_m_trans1_max_min_wert
{
	LABEL		"Max_Min_Werte";
	ITEMS
	{
		max_sensor_wert		(READ_ONLY),
		min_sensor_wert		(READ_ONLY)		
	}
}

MENU Tab_s_trans1_input_meassurelimit
{
	LABEL		[menu_input_measrange];
	ITEMS
	{
		sensor_low_limit,
		sensor_high_limit,
		cal_unit
	}
}

MENU Tab_m_trans1_input_meassurelimit
{
	LABEL		[menu_input_measrange];
	ITEMS
	{
		sensor_low_limit,
		sensor_high_limit,
		cal_unit 			(READ_ONLY)
	}
}
MENU Tab_s_input_table
{
	LABEL		[menu_input_table];
	ITEMS
	{
		lintab_edit_mode,
		lintab_no,
		IF(Anzahl_tabellenwerte >= 1)
		{
			wertepaar_x1,
			wertepaar_y1,
		}
		IF(Anzahl_tabellenwerte >=2)
		{
			wertepaar_x2,
			wertepaar_y2,
		}
		IF(Anzahl_tabellenwerte >=3)
		{
			wertepaar_x3,
			wertepaar_y3,
		}
		IF(Anzahl_tabellenwerte >=4)
		{
			wertepaar_x4,
			wertepaar_y4,
		}
		IF(Anzahl_tabellenwerte >=5)
		{
			wertepaar_x5,
			wertepaar_y5,
		}	
		IF(Anzahl_tabellenwerte >=6)
		{	
			wertepaar_x6,
			wertepaar_y6,
		}
		IF(Anzahl_tabellenwerte >=7)
		{
			wertepaar_x7,
			wertepaar_y7,
		}
		IF(Anzahl_tabellenwerte >=8)
		{
			wertepaar_x8,
			wertepaar_y8,
		}
		IF(Anzahl_tabellenwerte >=9)
		{
			wertepaar_x9,
			wertepaar_y9,
		}
		IF(Anzahl_tabellenwerte >=10)
		{
			wertepaar_x10,
			wertepaar_y10,
		}
		IF(Anzahl_tabellenwerte >=11)
		{
			wertepaar_x11,
			wertepaar_y11,
		}
		IF(Anzahl_tabellenwerte >=12)
		{
			wertepaar_x12,
			wertepaar_y12,
		}
		IF(Anzahl_tabellenwerte >=13)
		{
			wertepaar_x13,
			wertepaar_y13,
		}
		IF(Anzahl_tabellenwerte >=14)
		{
			wertepaar_x14,
			wertepaar_y14,
		}
		IF(Anzahl_tabellenwerte >=15)
		{
			wertepaar_x15,
			wertepaar_y15,
		}
		IF(Anzahl_tabellenwerte >=16)
		{
			wertepaar_x16,
			wertepaar_y16,
		}
		IF(Anzahl_tabellenwerte >=17)
		{
			wertepaar_x17,
			wertepaar_y17,
		}
		IF(Anzahl_tabellenwerte >=18)
		{
			wertepaar_x18,
			wertepaar_y18,
		}
		IF(Anzahl_tabellenwerte >=19)
		{
			wertepaar_x19,
			wertepaar_y19,
		}
		IF(Anzahl_tabellenwerte >=20)
		{
			wertepaar_x20,
			wertepaar_y20,
		}
		IF(Anzahl_tabellenwerte >=21)
		{
			wertepaar_x21,
			wertepaar_y21,
		}
		IF(Anzahl_tabellenwerte >=22)
		{
			wertepaar_x22,
			wertepaar_y22,
		}
		IF(Anzahl_tabellenwerte >=23)
		{
			wertepaar_x23,
			wertepaar_y23,
		}
		IF(Anzahl_tabellenwerte >=24)
		{
			wertepaar_x24,
			wertepaar_y24,
		}
		IF(Anzahl_tabellenwerte >=25)
		{
			wertepaar_x25,
			wertepaar_y25
		}
		Anzahl_tabellenwerte,
		IF((channel == 628)&&(lintab_edit_mode == 1))
		{
			lintab_status	
		}
	}
}

MENU Tab_s_trans2_fuellstand
{	
	LABEL	"Fllstandswerte";
	ITEMS
	{
		level_unten,
		level_oben,
		level_offset				
	}
}

VARIABLE  Anzahl_tabellenwerte	
{
	LABEL	"Anzahl Tabellenwerte";
	HELP	"";
	CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	1;
		MIN_VALUE		1;
		MAX_VALUE		24;
		DISPLAY_FORMAT	"u";
	}
	HANDLING
		IF(lintab_edit_mode == 1)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
	POST_READ_ACTIONS		{ meth_addition_anzahl_tabellenwerte }
}

COMMAND read_Anzahl_tabellenwerte
	{
		SLOT 1;
		INDEX 150;
		OPERATION READ;
		TRANSACTION
		{
			REQUEST
			{
			}
			REPLY
			{
				Anzahl_tabellenwerte
			}
		}
	}

METHOD meth_addition_anzahl_tabellenwerte 
{
	LABEL "Addition";
	DEFINITION
	{
		Anzahl_tabellenwerte++;
	}
}

MENU Tab_m_input
{
	LABEL		[menu_input];
	ITEMS
	{
		Tab_m_trans1
	}
}


MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_s_func1_private               // see SIPASTAI1_200.inc
	}
}

Tab_s_func1_private LIKE MENU Tab_s_func1
{
	REDEFINE	LABEL "Function Block 1 - Analog Input";
}

MENU Tab_s_func1
{
	LABEL		FUNC1_TITLE ;
	ITEMS
	{
		func1_st_rev,
		func1_pv_ftime,
		channel,
		out_value,
		out_status,
		AI_Targetmodus,
		AI_Modus,
		Tab_s_func1_pv_range,
		Tab_s_func1_outscale,
		Tab_s_func1_limits,
		Tab_s_func1_interface,
		TAB_s_func1_failsafe,
	}
}
MENU Tab_m_func1_interface
{
	LABEL		[menu_interface];
	ITEMS
	{
		func1_out_decimal_point	(READ_ONLY)
	}
}

MENU Tab_m_func1
{
	LABEL		FUNC1_TITLE ;
	ITEMS
	{
		func1_st_rev			 (READ_ONLY),
		func1_pv_ftime			 (READ_ONLY),
		channel					 (READ_ONLY),
		out_value				 (READ_ONLY),
		out_status				 (READ_ONLY),
		AI_Targetmodus			 (READ_ONLY),
		AI_Modus				 (READ_ONLY),
		Tab_m_func1_pv_range,
		Tab_m_func1_outscale,
		Tab_m_func1_limits,
		Tab_m_func1_interface,
		TAB_m_func1_failsafe
	}
}

MENU TAB_s_func1_failsafe
{
	LABEL		"Fehlerbehandlung";
	ITEMS
	{
		failsafe_wert,
		failsafe_type
	}
}

MENU TAB_m_func1_failsafe
{
	LABEL		"Fehlerbehandlung";
	ITEMS
	{
		failsafe_wert	 (READ_ONLY),
		failsafe_type	 (READ_ONLY)
	}
}

MENU Tab_m_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_m_func1_private               // see SIPASTAI1_200.inc
	}
}

Tab_m_func1_private LIKE MENU Tab_m_func1
{
	REDEFINE	LABEL "Function Block 1 - Analog Input";
}

MENU Tab_s_const
{
	LABEL		[menu_construct];
	ITEMS
	{
		Tab_s_trans1_const_design,
		Tab_s_trans1_const_proc
	}
}

MENU Tab_m_const
{
	LABEL		[menu_construct];
	ITEMS
	{
		Tab_m_trans1_const_design,
		Tab_m_trans1_const_proc
	}
}

MENU Tab_s_trans1_const_design
{
	LABEL	[menu_const_design];
	ITEMS
	{
		Tab_s_trans1_const_design_sensor
	}
}

MENU Tab_m_trans1_const_design
{
	LABEL	[menu_const_design];
	ITEMS
	{
		Tab_m_trans1_const_design_sensor
	}
}

MENU Tab_s_trans1_const_design_sensor
{
	LABEL	[menu_const_design_sensor];
	ITEMS
	{
//		Sensor_Fill_Fluid (READ_ONLY),
		Sensor_Fill_Fluid,
		Sensor_Diaphragm_Material (READ_ONLY),
		Sensor_max_static_pressure,
		sensor_oring_material
	}
}

MENU Tab_m_trans1_const_design_sensor
{
	LABEL	[menu_const_design_sensor];
	ITEMS
	{
		Sensor_Fill_Fluid			(READ_ONLY),
		Sensor_Diaphragm_Material	(READ_ONLY)
		Sensor_max_static_pressure	(READ_ONLY),
		sensor_oring_material		(READ_ONLY)
	}
}

MENU Tab_s_trans1_const_proc
{
	LABEL		[menu_const_proc];
	ITEMS
	{
		material_p_plus,
		material_p_minus
	}
}

MENU Tab_m_trans1_const_proc
{
	LABEL		[menu_const_proc];
	ITEMS
	{
		material_p_plus			(READ_ONLY),
		material_p_minus		(READ_ONLY)

	}
}

MENU Tab_s_interface
{
	LABEL		[menu_interface];
	ITEMS
	{
		Tab_s_interface_set
	}
}

MENU Tab_m_interface
{
	LABEL		[menu_interface];
	ITEMS
	{
		Tab_m_interface_set
	}
}

MENU Tab_s_interface_set
{
	LABEL		"Sensorabgleich";
	ITEMS
	{
		cal_point_lo 		(READ_ONLY),
		cal_point_hi 		(READ_ONLY),
		cal_min_span,
		IF(channel == 628)
		{
			sensor_offset_f
		}
		ELSE
		{
			sensor_offset
		}
		sensor_einheit		
	}
}

MENU Tab_m_interface_set
{
	LABEL		"Sensorabgleich";
	ITEMS
	{
		cal_point_lo 		(READ_ONLY),
		cal_point_hi 		(READ_ONLY),
		cal_min_span,
		IF(channel == 628)
		{
			sensor_offset_f			(READ_ONLY)
		}
		ELSE
		{
			sensor_offset			(READ_ONLY)
		}
		sensor_einheit				(READ_ONLY)	
	}
}

MENU Tab_s_certificates
{
	LABEL		[menu_certificates];
	ITEMS
	{
		phys_device_certification	(READ_ONLY)
	}
}
MENU Tab_m_certificates
{
	LABEL		[menu_certificates];
	ITEMS
	{
		phys_device_certification	(READ_ONLY)
	}
}


/***********************************************************************/
/*	  Components for standard view									   */
/***********************************************************************/

VARIABLE local_abort
{
	LABEL	"ABORT";
	CLASS	LOCAL;
	TYPE INTEGER
	{
		DEFAULT_VALUE	0;
	}
}
VARIABLE loc_device_id
{
	LABEL		"loc_device_id";
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		{	0,	"Hydrocont S"}
		{	1,	"CERABAR S" }
		{	2,	"CERABAR M" }
	}
}

VARIABLE std_V0H0
{
	LABEL		[std_V0H0];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_display_enum]}
	}
	HANDLING	READ;
}

VARIABLE std_V0H3
{
	LABEL		[trans_auto_meas_begin];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V0H3_enum]}
	}
	HANDLING	READ;
}

std_V0H4		LIKE VARIABLE std_V0H3
{
	REDEFINE LABEL		[trans_auto_meas_end];
}

VARIABLE std_V0H6
{
	LABEL		[trans_auto_bias_press];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V0H6_enum]}
	}
	HANDLING	READ;
}


VARIABLE std_V2H3
{
	LABEL		[std_V2H3];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_min_max_enum]}
	}
	HANDLING	READ;
}

std_V2H4		LIKE VARIABLE std_V2H3
{
	REDEFINE LABEL		[std_V2H4];
}

std_V2H7		LIKE VARIABLE std_V2H3
{
	REDEFINE LABEL		[std_V2H7];
}

std_V2H8		LIKE VARIABLE std_V2H3
{
	REDEFINE LABEL		[std_V2H8];
}

std_V2H6		LIKE VARIABLE std_V0H0
{
	REDEFINE LABEL		[std_V2H6];
}

VARIABLE std_V2H9
{
	LABEL		[std_V2H9];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V2H9_enum]}
	}
	HANDLING	READ;
}

VARIABLE std_V3H6
{
	LABEL		[trans_lin_tab_edit_mode];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V3H6_enum]}
	}
	HANDLING	READ;
}

std_V3H7		LIKE VARIABLE std_V3H6
{
	REDEFINE LABEL		[std_V3H7];
}

std_V3H8		LIKE VARIABLE std_V3H6
{
	REDEFINE LABEL		[trans_lin_table_x];
}

std_V3H9		LIKE VARIABLE std_V3H6
{
	REDEFINE LABEL		[trans_lin_table_y];
}

VARIABLE std_V7H4
{
	LABEL		[std_V7H4];
	HELP		[trans_cal_point_lo_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V7H4_5_enum]}
	}
	HANDLING	READ;
}

std_V7H5		LIKE VARIABLE std_V7H4
{
	REDEFINE LABEL		[std_V7H5];
	REDEFINE HELP		[trans_cal_point_hi_help];
}

std_V7H8		LIKE VARIABLE std_V0H0
{
	REDEFINE LABEL		[std_V7H8];
}


VARIABLE std_V9H9
{
	LABEL		[std_V9H9];
	HELP		[phys_write_locking_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V9H9_enum]}
	}
	HANDLING	READ;
}


COLLECTION OF VARIABLE profil_par
{
	MEMBERS
	{
		std_V0H0,		trans1_primary_value,		[std_V0H0];
		std_V0H9,		cal_unit,			[std_V0H9];	
		std_V3H3,		trans1_primary_value_unit,	[std_V3H3];


		std_V7H6,		sensor_low_limit,	[std_V7H6];	
		std_V7H7,		sensor_high_limit,	[std_V7H7];	
		std_V9H7,		trans1_trimmed_value,		[std_V9H7];

		std_VAH0,		phys_tag_desc,				[std_VAH0];
		std_VAH1,		phys_message,				[std_VAH1];
		std_VAH2,		phys_serial_num,			[std_VAH2];
		std_VAH3,		trans1_sensor_num,			[std_VAH3];
		std_VAH4,		material_p_plus,	[std_VAH4];
		std_VAH5,		material_p_minus, [std_VAH5];
		std_VAH7,		Sensor_Diaphragm_Material, [std_VAH7];
		std_VAH8,		Sensor_Fill_Fluid, [std_VAH8];
	}
}

/*

METHOD meth_calibrate_reference
{
	LABEL		[meth_calibrate_reference];
	DEFINITION
	{
		int ret;
		long var_id[1];

		add_abort_method (meth_abort);

		// ---------- Reset ----
		//ret = ACKNOWLEDGE ([ack_set_std_V0H3]);
		ret = SELECT_FROM_LIST ([ack_set_std_V0H3], [no_yes]);

		if (ret == 1)
		{
			phys_factory_reset = 2380;
			ret = WriteCommand(write_phys_factory_reset);  //V2H9
			if (ret >= ID_FC_ERROR) process_abort();
		}

		// ---------- trans1_ms_linearisation_mode ----
//fbi		ret = GET_DEV_VAR_VALUE([ack_choice_lin_type], trans1_ms_linearisation_mode);
//		ret = GET_DEV_VAR_VALUE([ack_choice_lin_type], linearisation_mode);		//fbi
		if (ret)	process_abort();	// ok <=> 0
		ret = WriteCommand(write_trans1_ms_linearisation_mode);
		if (ret >= ID_FC_ERROR) process_abort();

		// Unit ermitteln
		if (linearisation_mode == 0)
			var_id[0] = VARID(cal_unit);
		else
			var_id[0] = VARID(trans1_primary_value_unit);

		// ---------- Besttigung: Druck fr 'Fllstand leer' bernehmen
		ret = ACKNOWLEDGE ([ack_apply_auto_meas_begin]);
		if (ret)	process_abort();	// ok <=> 0
//fbi		ret = WriteCommand(write_trans1_ms_lower_range_value_auto); //V0H3
		if (ret >= ID_FC_ERROR) process_abort();


		// ---------- aktuellen Fllstand fr 'Fllstand leer' eintragen
//fbi		ret = get_dev_var_value([ack_choice_displ_lin_beg], var_id, trans1_ms_display_lowrange_val);
		if (ret)	process_abort();	// ok <=> 0
//fbi 		ret = WriteCommand(write_trans1_ms_display_lowrange_val);
		if (ret >= ID_FC_ERROR) process_abort();

		// ---------- Besttigung: Druck fr 'Fllstand voll' bernehmen
		ret = ACKNOWLEDGE ([ack_apply_auto_meas_end]);
		if (ret)	process_abort();	// ok <=> 0
//fbi		ret = WriteCommand(write_trans1_ms_upper_range_value_auto); //V0H4
		if (ret >= ID_FC_ERROR) process_abort();


		// ---------- aktuellen Fllstand fr 'Fllstand voll' eintragen
//fbi		ret = get_dev_var_value([ack_choice_displ_lin_end], var_id, trans1_ms_display_uprange_val);
		if (ret)	process_abort();	// ok <=> 0
//fbi		ret = WriteCommand(write_trans1_ms_display_uprange_val);
		if (ret >= ID_FC_ERROR) process_abort();


		// ---------- Einheit nach Linearisierung whlen
		ret = GET_DEV_VAR_VALUE([ack_choice_primary_value_unit], trans1_primary_value_unit);
		if (ret)	process_abort();	// ok <=> 0
		ret = WriteCommand(write_trans1_primary_value_unit);
		if (ret >= ID_FC_ERROR) process_abort();


		ACKNOWLEDGE([ack_calibration_success]);
		//DELAY(3,"ret = "+itoa(ret));

	}
}
*/

METHOD meth_abort
{
	DEFINITION
	{
		local_abort = 1; //Abbruch
		ACKNOWLEDGE([acknowledge_process_aborted]);
	}
}

METHOD pre_write_upload_variables
{
	DEFINITION
	{
		ReadCommand(read_phys_security_locking);
		if  (ivar_value(phys_security_locking) == 0){
			ACKNOWLEDGE ([security_locked]);
		}
	}
}
VARIABLE loc_limit_error
{
	LABEL	"Local limit error";
	CLASS	LOCAL;
	TYPE INTEGER
	{
		DEFAULT_VALUE	0; //kein Fehler
	}
}

METHOD meth_check_lokal_limits
{
	DEFINITION
	{
		float loc_lolo, loc_lo, loc_hi, loc_hihi;
		loc_lolo = fvar_value(func1_lo_lo_lim);
		loc_lo   = fvar_value(func1_lo_lim);
		loc_hihi = fvar_value(func1_hi_hi_lim);
		loc_hi   = fvar_value(func1_hi_lim);
		iassign(loc_limit_error, 0);  // kein Fehler

		if (loc_lolo > loc_lo){
			ACKNOWLEDGE ([loclolo_bigger_loclo]);
			iassign(loc_limit_error, 1); // Fehler
		}
		if (loc_hihi < loc_hi){
			ACKNOWLEDGE ([lochihi_smaller_lochi]);
			iassign(loc_limit_error, 1); // Fehler
		}
		if (loc_hi < loc_lo){
			ACKNOWLEDGE ([lochi_smaller_loclo]);
			iassign(loc_limit_error, 1); // Fehler
		}
	}
}

METHOD meth_write_limits
{
	DEFINITION
	{
		float loc_lolo, loc_lo, loc_hi, loc_hihi;
		float act_lolo, act_lo, act_hi, act_hihi;
		loc_lolo = fvar_value(func1_lo_lo_lim);
		loc_lo   = fvar_value(func1_lo_lim);
		loc_hihi = fvar_value(func1_hi_hi_lim);
		loc_hi   = fvar_value(func1_hi_lim);
		ReadCommand(read_func1_lo_lo_lim);
		ReadCommand(read_func1_lo_lim);
		ReadCommand(read_func1_hi_hi_lim);
		ReadCommand(read_func1_hi_lim);
		act_lolo = fvar_value(func1_lo_lo_lim);
		act_lo   = fvar_value(func1_lo_lim);
		act_hihi = fvar_value(func1_hi_hi_lim);
		act_hi   = fvar_value(func1_hi_lim);

		if (0 == ivar_value(loc_limit_error)){
			fassign(func1_lo_lo_lim, loc_lolo);
			fassign(func1_lo_lim, loc_lo);
			fassign(func1_hi_hi_lim, loc_hihi);
			fassign(func1_hi_lim, loc_hi);
			if (loc_lolo > act_lo){
				WriteCommand(write_func1_lo_lim);
				WriteCommand(write_func1_lo_lo_lim);
			} else {
				WriteCommand(write_func1_lo_lo_lim);
				WriteCommand(write_func1_lo_lim);
			}
			if (loc_hihi < act_hi){
				WriteCommand(write_func1_hi_lim);
				WriteCommand(write_func1_hi_hi_lim);
			} else {
				WriteCommand(write_func1_hi_hi_lim);
				WriteCommand(write_func1_hi_lim);
			}
		}
	}
}


VARIABLE func1_pv_ftime
{
	LABEL		[func_pv_ftime];
	HELP		[func_pv_ftime_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0;
		MIN_VALUE		0;
		MAX_VALUE		40;
	}
	CONSTANT_UNIT	[sec];
	HANDLING	READ & WRITE;
}

VARIABLE func1_hi_hi_lim
{
	LABEL		[limit_hi_hi];
	HELP		[limit_hi_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_hi_hi_lim;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}

VARIABLE func1_hi_lim
{
	LABEL		[limit_hi];
	HELP		[limit_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_hi_lim;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}

VARIABLE func1_lo_lim
{
	LABEL		[limit_lo];
	HELP		[limit_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_lo_lim;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}

VARIABLE func1_lo_lo_lim
{
	LABEL		[limit_lo_lo];
	HELP		[limit_lo_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_lo_lo_lim;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}


MENU upload_variables  /* Schreiben ins Feldgert */
{
	LABEL		[menu_load_to_device];
	PRE_WRITE_ACTIONS
	{
		//pre_write_upload_variables,
		meth_check_lokal_limits,
		meth_write_limits,
		meth_channel_writing
	}
	ITEMS
	{
		IF (phys_security_locking != 0){
			//phys_ms_matrix_last_err_code,
			// von trans1_ms_linearisation_mode abhngige Variablen
			//trans1_ms_linearisation_mode,
			/*IF (linearisation_mode!=0) //Bi V1.84 start
			{
				trans1_ms_display_lowrange_val,
				trans1_ms_display_uprange_val,
				trans1_ms_density_factor,			
			}*///Bi V1.84 end
			//trans1_primary_value_unit,
			// Profile 2.0
			phys_tag_desc,
			phys_descriptor,
			phys_message,
			phys_install_date,
			cal_unit,
			func1_pv_ftime,
			channel,
			func1_out_decimal_point,
			Sensor_Fill_Fluid,
			pv_unit,
			pv_lower_range_value,
			pv_upper_range_value,
			pv_f_unit,
			cal_type,
			func1_out_unit,
			func1_out_lower_range_value,
			func1_out_upper_range_value,
			AI_Targetmodus,
			Targetmodus,	

			func1_lo_lo_lim,
			func1_lo_lim,
			func1_hi_lim,
			func1_hi_hi_lim,
			func1_alarm_hys,
			lintab_edit_mode,	
			material_p_minus,
			material_p_plus,
			wartungsintervall,
		//	wartungstimer,
			ueberlastzaehler,
			lintab_no,
			max_sensor_wert,
			min_sensor_wert,
			sensor_offset,
			sensor_offset_f,	
			sensor_oring_material,
			failsafe_type,
			failsafe_wert,
			level_unten,
			level_oben,
			level_offset
		}		
	}
	POST_WRITE_ACTIONS 
	{
		meth_write_lin_table,
		meth_post_write
	}
}


MENU download_variables  /* Lesen aus Feldgert */
{
	LABEL   [menu_load_to_PC];
	POST_READ_ACTIONS 
	{
		meth_check_lokal_limits,
		meth_read_lin_table
	}
	PRE_READ_ACTIONS  
	{
		meth_channel_reading,
		meth_read_lin_mode
	}
	ITEMS
	{
		cal_unit,
		trans1_trimmed_value,
		trans1_sensor_num,
		sensor_oring_material,
		//trans1_primary_value_unit,
		phys_tag_desc,
		phys_descriptor,
		phys_message,
		phys_manufacturer_id,
		device_id,
		phys_serial_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_blk_profile_rev,
		phys_install_date,
		phys_st_rev,
		trans1_st_rev,
		trans1_primary_value_type,
		sensor_low_limit,
		sensor_high_limit,
		lintab_edit_mode,
		lintab_no,
		func1_st_rev,
		func1_out_decimal_point,
		func1_pv_ftime,
		channel,
		pv_unit,
		pv_lower_range_value,
		pv_upper_range_value,
		pv_f_unit
		trans2_st_rev,
		cal_type,
		AI_Targetmodus,
		AI_Modus,	
		Targetmodus,
		func1_out_unit,
		func1_out_lower_range_value,
		func1_out_upper_range_value,
		func1_lo_lo_lim,
		func1_lo_lim,
		func1_hi_lim,
		func1_hi_hi_lim,
		func1_alarm_hys,
		//trans1_ms_Sensor_Fill_Fluid,
		Sensor_Fill_Fluid,
		Sensor_Diaphragm_Material,
		material_p_plus,
		material_p_minus,
		channel,
		cal_point_lo,
		cal_point_hi,
		cal_min_span,
		wartungsintervall,
		wartungstimer,
		ueberlastzaehler,
		max_sensor_wert,
		min_sensor_wert,
		sensor_offset,
		sensor_offset_f,
		Sensor_max_static_pressure,
		sensor_rohwert,
		sensor_einheit,
		failsafe_type,
		failsafe_wert,
		nennnullpunkt,
		nennendpunkt,
		primary_value_fuellstand,
		secondary_value_1_f,
		secondary_value_2_f,
		secondary_value_1_d,
		secondary_value_2_d,
		primary_value_druck,
		level_unten,
		level_oben,
		level_offset,
		Anzahl_tabellenwerte,
		out_value,
		lintab_status,
		
		phys_device_certification
	}
	PRE_WRITE_ACTIONS	
	{
		meth_read_lin_mode
	}
	PRE_EDIT_ACTIONS	
	{
		meth_read_lin_mode
	}
}

METHOD meth_read_lin_mode
{
	DEFINITION
	{
		ReadCommand(read_trans1_ms_lintab_edit_mode);
	}
}

METHOD meth_channel_reading
{
	DEFINITION
	{
		ReadCommand(read_channel);
	}
}

METHOD meth_channel_writing
{
	DEFINITION
	{
		WriteCommand(write_channel);
	}
}

METHOD meth_read_lin_table
{
	DEFINITION
	{
		unsigned int i;
		
		/*op_code_1 = 1;	

		WriteCommand(write_op_code);*/
	
		for(i=0; i< Anzahl_tabellenwerte;i++)
		{
			lintab_no = i;

			WriteCommand(write_trans1_ms_lintab_no);

			ReadCommand(read_trans1_ms_lintab_level);
			

			if(i==0)
			{	
				wertepaar_x1 = lintab_level;
				wertepaar_y1 = lintab_volume;
			}

			if(i==1)
			{	
				wertepaar_x2 = lintab_level;
				wertepaar_y2 = lintab_volume;
			}

			if(i==2)
			{	
				wertepaar_x3 = lintab_level;
				wertepaar_y3 = lintab_volume;
			}

			if(i==3)
			{	
				wertepaar_x4 = lintab_level;
				wertepaar_y4 = lintab_volume;
			}

			if(i==4)
			{	
				wertepaar_x5 = lintab_level;
				wertepaar_y5 = lintab_volume;
			}

			if(i==5)
			{	
				wertepaar_x6 = lintab_level;
				wertepaar_y6 = lintab_volume;
			}

			if(i==6)
			{	
				wertepaar_x7 = lintab_level;
				wertepaar_y7 = lintab_volume;
			}

			if(i==7)
			{	
				wertepaar_x8 = lintab_level;
				wertepaar_y8 = lintab_volume;
			}

			if(i==8)
			{	
				wertepaar_x9 = lintab_level;
				wertepaar_y9 = lintab_volume;
			}

			if(i==9)
			{	
				wertepaar_x10 = lintab_level;
				wertepaar_y10 = lintab_volume;
			}

			if(i==10)
			{	
				wertepaar_x11 = lintab_level;
				wertepaar_y11 = lintab_volume;
			}

			if(i==11)
			{	
				wertepaar_x12 = lintab_level;
				wertepaar_y12 = lintab_volume;
			}

			if(i==12)
			{	
				wertepaar_x13 = lintab_level;
				wertepaar_y13 = lintab_volume;
			}

			if(i==13)
			{	
				wertepaar_x14 = lintab_level;
				wertepaar_y14 = lintab_volume;
			}

			if(i==14)
			{	
				wertepaar_x15 = lintab_level;
				wertepaar_y15 = lintab_volume;
			}

			if(i==15)
			{	
				wertepaar_x16 = lintab_level;
				wertepaar_y16 = lintab_volume;
			}

			if(i==16)
			{	
				wertepaar_x17 = lintab_level;
				wertepaar_y17 = lintab_volume;
			}

			if(i==17)
			{	
				wertepaar_x18 = lintab_level;
				wertepaar_y18 = lintab_volume;
			}

			if(i==18)
			{	
				wertepaar_x19 = lintab_level;
				wertepaar_y19 = lintab_volume;
			}

			if(i==19)
			{	
				wertepaar_x20 = lintab_level;
				wertepaar_y20 = lintab_volume;
			}

			if(i==20)
			{	
				wertepaar_x21 = lintab_level;
				wertepaar_y21 = lintab_volume;
			}

			if(i==21)
			{	
				wertepaar_x22 = lintab_level;
				wertepaar_y22 = lintab_volume;
			}

			if(i==22)
			{	
				wertepaar_x23 = lintab_level;
				wertepaar_y23 = lintab_volume;
			}

			if(i==23)
			{	
				wertepaar_x24 = lintab_level;
				wertepaar_y24 = lintab_volume;
			}

			if(i==24)
			{	
				wertepaar_x25 = lintab_level;
				wertepaar_y25 = lintab_volume;
			}
		}
	}
}

METHOD meth_write_lin_value //Schreiben einzelner Linearisierungswertepaare ber die Reiterfunktion "Linearisierung" im Men "Gert"
{
	LABEL "Setzen";
	DEFINITION
	{
		unsigned int i;

		WriteCommand(write_trans1_ms_lintab_edit_mode);	
		
		if(lintab_edit_mode == 1)
		{
			op_code_1 = 1;	
	
			WriteCommand(write_op_code);	
		
			WriteCommand(write_trans1_ms_lintab_no);
		
			WriteCommand(write_trans1_ms_lintab_level);	

			op_code_1 = 3;	

			WriteCommand(write_op_code);

			ReadCommand(read_lintab_status);
		}		
	}
}

METHOD	meth_read_lin_value
{
	LABEL "Lesen";
	DEFINITION
	{				
		WriteCommand(write_trans1_ms_lintab_no);
		
		ReadCommand(read_trans1_ms_lintab_level);		
	}
}

METHOD meth_write_lin_table
{
	DEFINITION
	{
		unsigned int i;
		
		op_code_1 = 1;	

		WriteCommand(write_op_code);
	
		for(i=0; i< Anzahl_tabellenwerte;i++)
		{
			lintab_no = i;

			WriteCommand(write_trans1_ms_lintab_no);

			if(i==0)
			{	
				lintab_level = wertepaar_x1;
				lintab_volume = wertepaar_y1;
			}

			if(i==1)
			{	
				lintab_level = wertepaar_x2;
				lintab_volume = wertepaar_y2;
			}

			if(i==2)
			{	
				lintab_level = wertepaar_x3;
				lintab_volume = wertepaar_y3;
			}

			if(i==3)
			{	
				lintab_level = wertepaar_x4;
				lintab_volume = wertepaar_y4;
			}

			if(i==4)
			{	
				lintab_level = wertepaar_x5;
				lintab_volume = wertepaar_y5;
			}

			if(i==5)
			{	
				lintab_level = wertepaar_x6;
				lintab_volume = wertepaar_y6;
			}

			if(i==6)
			{	
				lintab_level = wertepaar_x7;
				lintab_volume = wertepaar_y7;
			}

			if(i==7)
			{	
				lintab_level = wertepaar_x8;
				lintab_volume = wertepaar_y8;
			}

			if(i==8)
			{	
				lintab_level = wertepaar_x9;
				lintab_volume = wertepaar_y9;
			}

			if(i==9)
			{	
				lintab_level = wertepaar_x10;
				lintab_volume = wertepaar_y10;
			}

			if(i==10)
			{	
				lintab_level = wertepaar_x11;
				lintab_volume = wertepaar_y11;
			}

			if(i==11)
			{	
				lintab_level = wertepaar_x12;
				lintab_volume = wertepaar_y12;
			}

			if(i==12)
			{	
				lintab_level = wertepaar_x13;
				lintab_volume = wertepaar_y13;
			}

			if(i==13)
			{	
				lintab_level = wertepaar_x14;
				lintab_volume = wertepaar_y14;
			}

			if(i==14)
			{	
				lintab_level = wertepaar_x15;
				lintab_volume = wertepaar_y15;
			}

			if(i==15)
			{	
				lintab_level = wertepaar_x16;
				lintab_volume = wertepaar_y16;
			}

			if(i==16)
			{	
				lintab_level = wertepaar_x17;
				lintab_volume = wertepaar_y17;
			}

			if(i==17)
			{	
				lintab_level = wertepaar_x18;
				lintab_volume = wertepaar_y18;
			}

			if(i==18)
			{	
				lintab_level = wertepaar_x19;
				lintab_volume = wertepaar_y19;
			}

			if(i==19)
			{	
				lintab_level = wertepaar_x20;
				lintab_volume = wertepaar_y20;
			}

			if(i==20)
			{	
				lintab_level = wertepaar_x21;
				lintab_volume = wertepaar_y21;
			}

			if(i==21)
			{	
				lintab_level = wertepaar_x22;
				lintab_volume = wertepaar_y22;
			}

			if(i==22)
			{	
				lintab_level = wertepaar_x23;
				lintab_volume = wertepaar_y23;
			}

			if(i==23)
			{	
				lintab_level = wertepaar_x24;
				lintab_volume = wertepaar_y24;
			}

			if(i==24)
			{	
				lintab_level = wertepaar_x25;
				lintab_volume = wertepaar_y25;
			}

			WriteCommand(write_trans1_ms_lintab_level);
		}
	
		op_code_1 = 3;	

		WriteCommand(write_op_code);

		ReadCommand(read_lintab_status);
	}
}
METHOD meth_post_write
{
	DEFINITION
	{
//		ACKNOWLEDGE("meth_post_write)");
		ReadCommand(read_func1_out_scale);
		ReadCommand(read_func1_alarm_hys);
	}
}



METHOD meth_reset_pressure
{
	LABEL			[reset];
	HELP			[reset_press_pointer_Help];
	DEFINITION
	{
		float f1;
		int i1;
		f1=fvar_value(trans1_primary_value);
		fassign(min_sensor_wert, f1);
		WriteCommand(write_min_sensor_wert);
		fassign(max_sensor_wert , f1);
		WriteCommand(write_max_sensor_wert);
		i1=0;
	}
}

METHOD meth_wartungsintervallschreiben
{
	LABEL	"bertragen";
	
	DEFINITION
	{	
		WriteCommand(write_wartungsintervall);
	}
}



